### A Pluto.jl notebook ###
# v0.19.41

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    quote
        local iv = try Base.loaded_modules[Base.PkgId(Base.UUID("6e696c72-6542-2067-7265-42206c756150"), "AbstractPlutoDingetjes")].Bonds.initial_value catch; b -> missing; end
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : iv(el)
        el
    end
end

# ╔═╡ a145e2fe-a903-11eb-160f-df7ea83fa3e6
begin
	using PlotlyBase, HypertextLiteral, PlutoUI, PlutoPlotly
	using CSV, DataFrames, Dates, PeriodicalDates, NLsolve
	#import PlotlyJS: savefig
end

# ╔═╡ 943edb36-acc8-4b2a-94ab-c544f9eb279b
md"""
# Week 10 - Rampant Inflation vs the Fear of Deflation

# Exercises

**Macroeconomics, ISCTE-IUL**
"""

# ╔═╡ 1245aef9-18ce-42f5-af82-c2e6cce70798
md"""
**Vivaldo Mendes, Ricardo Gouveia-Mendes, Luís Clemente-Casinhas; May 2024**
"""

# ╔═╡ 4618a663-f77e-4ccc-9b00-e84dbd5beb34
md"""
### Packages
"""

# ╔═╡ 74de9f66-d5b4-4e0f-a75d-5177b1842191
begin
	function Base.show(io::IO, mimetype::MIME"text/html", plt::PlotlyBase.Plot)
       # Remove responsive flag on the plot as we handle responsibity via ResizeObeserver and leaving it on makes the div flickr during updates
	hasproperty(plt,:config) && plt.config.responsive && (plt.config.responsive = false)   
	show(io,mimetype, @htl("""
			<div>
			<script id=asdf>
			const {plotly} = await import("https://cdn.plot.ly/plotly-2.2.0.min.js")
			const PLOT = this ?? document.createElement("div");
		

		
			Plotly.react(PLOT, $(HypertextLiteral.JavaScript(PlotlyBase.json(plt))));


		
			const pluto_output = currentScript.parentElement.closest('pluto-output')

			const resizeObserver = new ResizeObserver(entries => {
				Plotly.Plots.resize(PLOT)
			})

			resizeObserver.observe(pluto_output)

			invalidation.then(() => {
				resizeObserver.disconnect()
			})
		
			return PLOT
			</script>
			</div>
	"""))
	end
end

# ╔═╡ 0bc2eb14-3b5a-4203-82dd-3ef2044a2c93
md"""
## Exercise 1. Inflation targeting
"""

# ╔═╡ 7e025b57-5962-4ab8-85a0-a3cad37b1be5
Resource("http://ebs.de.iscte.pt/ECB_Rules.png", :width=>600)

# ╔═╡ 5999a598-0408-44f1-bd33-c4d0fa5a6006
md"""

On 8 July 2021, the European Central Bank (ECB) announced a revision of its monetary policy strategy for the first time since its creation in 1998. From the article above in the Financial Times, one can read:

>*"The central bank said its new target of 2 per cent was symmetric, “meaning negative and positive deviations of inflation from the target are equally undesirable”. The new target is a medium-term objective with flexibility to fluctuate in either direction in the short term [and] said it could tolerate temporary moves beyond that point, in a shift that gives policymakers flexibility to keep interest rates at historic lows for longer”.*

👉 a) Figure 1 plots the data about inflation in the EuroZone (EZ) and Portugal since 1998. Why do you think the ECB stresses "the symmetric deviations of inflation from the target"?

👉 b) Why do you think the article stresses "...in a shift that gives policymakers flexibility to keep interest rates at historic lows for longer”?

👉 c) For Portugal and the Eurozone, what is the mean for the inflation deviations from the target, according to the old strategy (we will call it "Loss1")? And according to the new strategy ("Loss2")?

"""

# ╔═╡ 3d27554e-be8a-41a8-9fbf-1c7f3bc2cd84
md"""
| Loss to society              |   | mean    |   | min     |   | median  |   | max     |   |standard dev. |
|:-------                      |---|:------- |---|:--------|---|:--------|---|:--------|---|:-------      |
| Euro Zone (Ceiling)          |   | 0.1799  |   | 0.0     |   | 0.0     |   | 2.1     |   | 0.3579       |
| Euro Zone (True target)      |   | 0.7568  |   | 0.0     |   | 0.6     |   | 2.6     |   | 0.6422       |
|                              |   |         |   |         |   |         |   |         |   |              |
| Portugal  (Ceiling)          |   | 0.5081  |   | 0.0     |   | 0.0     |   | 3.1     |   | 0.7180       |
| Portugal  (True target)      |   | 1.2081  |   | 0.0     |   | 1.2     |   | 3.8     |   | 0.8148       |
"""

# ╔═╡ 7d4589e5-37a5-4803-97bc-24c9a8ea61a5
md"""
!!! answer "Answer (a)"

	The ECB stresses "the symmetric deviations of inflation from the target" to clarify that it will not tolerate inflation rates below 2%, no matter how low and stable they may be. Inflation above target and below target should be treated in the same way.

"""

# ╔═╡ 14a93d0a-2005-4406-9150-319d6583a518
md"""
!!! answer "Answer (b)"

	Usually, using the target as a "ceiling" leads to a situation where inflation is too low. In the summer of 2021, the ECB feared deflation and wanted to increase inflation to the 2% target. Changing the strategy to "symmetric deviations" would lead, on average, to higher inflation. Moreover, higher inflation would require keeping interest rates very low for an extended period.

"""

# ╔═╡ 41c7afb6-a57b-45a7-8b9d-bb30902aab8b
md"""
!!! answer "Answer (c)"

	In the previous figure, we can easily observe why the central bank's loss function is dramatically affected by having only positive deviations from the target as its argument or by having both positive and negative deviations as arguments. The first case can be written in the following way:

	$$\begin{equation}
        Loss=
        \left\{ \begin{array}{cc}
            \pi - \pi^{_T} \ \ \ \ , & \pi > \pi^{_T}  \\
            \quad 0 \ \ \qquad , & \ \quad \text{otherwise}
        \end{array} \right.
    \end{equation}$$ 

	while the second case has to be written using the absolute value operator:

	$$Loss=|\pi - \pi^{_T}|$$

	The left-hand panel (Fig. 2) shows the first case. The right-hand side panel (Fig. 3) shows the second case; the losses are significantly much more significant than those in the left panel. This fact is the fundamental reason the ECB has decided to produce a drastic reform in its monetary policy strategy after more than twenty years since it started to operate.

	The *means* of the Loss function according to each rule (the old strategy, which considered only positive deviations from the target, and the new strategy, which includes both positive and negative deviations) are presented in the following table. 

	$$\begin{aligned}
	&\text { Table 1: Mean of the Loss function }\\
	&\begin{array}{lcc}
	\hline & \text { Positive deviations } & \text { Both deviations } \\
	\hline \text { Eurozone } & 0.1799 & 0.7568 \\
	\text { Portugal } & 0.5081 & 1.2081 \\
	\hline
	\end{array}
	\end{aligned}$$



"""

# ╔═╡ 0836abe7-5ea6-4189-b783-a2215b6acd72
md"""
## Exercise 2. The Taylor rule
"""

# ╔═╡ 4ce820d4-9eb2-4acd-92c7-820cf46d08ae
md"""

We will use statistical data about the variables crucial for the analysis of the Taylor Rule: real GDP, Potential GDP, inflation rate, and the nominal interest rate (Federal Funds Rate). The data is in the file "Taylor.csv" and can be found in the table below. We calculate and plot the Monetary Policy Rule for **three different scenarios**:

- The MP rule, as considered in our textbook, with $\lambda = 0.5, \ \overline{r}=2\%, \pi^{_T}=2\%$. For the calculations, we use rates expressed by *percentage points*. This means that $\overline{r}=2, \pi^{_T}=2$, which makes the calculus easier to understand and corresponds to how FRED presents the data. 

- The original Taylor Rule with equal weights for the inflation gap and the output gap $(\lambda_{\pi}=\lambda_{y}=0.5)$.

- The (New) Taylor Rule with a higher weight for the output gap: $(\lambda_{\pi}=0.5,\ \lambda_{y}=1.0)$. 

👉 a) Do you consider any of those three rules to explain well the Central Bank of the USA (Fed) decisions concerning the Fed Funds Rate?

👉 b) Can you provide clear evidence that having a Taylor Rule in autopilot may lead to extreme punishments for the economy?

👉 c) Given the evidence in these three rules, are monetary policy rules useless?

"""

# ╔═╡ d0e70b80-1e84-412c-9e5f-0161a0b0a935
md"""
Let us insert the data into Pluto:
"""

# ╔═╡ 2207f310-b6e0-40ca-9d11-6bd90adbd997
md"""
#### The Textbook rule
"""

# ╔═╡ 66f39956-3665-4259-b10c-a82f3985b54b
Taylor= CSV.read("Taylor.csv", DataFrame)

# ╔═╡ 57d7d8ed-dce5-4177-b92b-1114b538814d
begin
	r̄ = 2 ;	λ = 0.5 ; λ_π = 0.5 ; λ_y = 0.5 ; πᵀ = 2.0 							# Exogenous variables & parameters 
	
	Y = Taylor[:,3] ; Yᴾ = Taylor[:,2] ; π = Taylor[:,4] ; i = Taylor[:,5] 		# Data about Y, Yᴾ, π and i
end;

# ╔═╡ 1dc9dce6-d373-4eb7-8e30-1030160accb4
Taylor_textbook = r̄ .+ (1.0 .+ λ) .* π;

# ╔═╡ b0679f0a-69fc-427d-aae5-b3a243ccd407
#savefig(p10_11, "Taylor_textbook.png", width=800, height=400, scale=10);

# ╔═╡ 3b119e3e-e9bf-4426-9a4e-509504a7a122
md"""
#### The standard Taylor rule
"""

# ╔═╡ c496f682-73c2-40a8-88bf-c5f8554b9e3c
Taylor_standard = r̄ .+ π .+  λ_π .* (π .- πᵀ) .+ λ_y .* (100 .* ((Y .- Yᴾ) ./ Yᴾ));

# ╔═╡ 211db303-2224-4fb0-af03-f3558a27d206


# ╔═╡ cace5be5-7a28-42ea-a958-d8eb5cced10d
md"""
#### The New Taylor Rule: more emphasis on the output-gap
"""

# ╔═╡ ee4cce74-40c5-41e6-b74e-122617a21d0d
md"""
!!! note

	The slider below `Δλ_y=0.5` tells us that the central bank is more concerned about the output-gap than in the original version of the rule (where `λ_y=0.5` and `Δλ_y=0`). See what happens by changing the value of this slider.

"""

# ╔═╡ 5a4c70b0-4f7c-4ef3-aabf-af1c46978637
md"""
`Δλ_y = `$(@bind Δλ_y Slider(-0.5:0.25:5.0, default=0.5, show_value=true))
"""

# ╔═╡ 077586e0-70a0-4322-a531-3c71b6eab95f
Taylor_new = r̄ .+ π .+  λ_π .* (π .- πᵀ) .+ (λ_y .+ Δλ_y) .* (100 .* ((Y .- Yᴾ) ./ Yᴾ));

# ╔═╡ b53240b4-4fc7-4b07-acc2-b5381bcd6c86
md"""
!!! tip "Answer (a)"

	Given the evidence presented by the figures above, it seems clear that none of the three rules explains how the Fed has conducted monetary policy since the early 1960s. The gaps between any one of those rules and the Fed Funds Rate (FFR) are too large to be ignored. 

	Nevertheless, what we named the New Taylor Rule seems to be the best, particularly if we consider the period since the early 1990s.

"""

# ╔═╡ 87f6de5e-ccbe-4295-a37f-123cfccaf3e8
md"""
!!! tip "Answer (b)"

	There are several periods where the Fed Funds Rate was systematically much lower (or much higher) than the value given by the monetary policy rules we studied here. However, let us concentrate on a recent period (since 2008: the Great Recession) because we know what has been occurring in the US economy. 

	This economy (and other major developed economies) performed poorly when the financial crisis burst in 2008:  low GDP growth rates, high unemployment, timid investment expenditures, high uncertainty and risk, and low consumer confidence. In the summer of 2008, the Fed decided to bring the FFR to zero, while the rules would suggest that the rates should be close to 7, 8, or 9%. Moreover, while the US economy is currently not in an economic boom (real GDP is still lower than Potential GDP), the three rules propose that the FFR should be higher than 10%. Put it bluntly: it would be entirely insane for the Fed to raise interest rates to 10% or more in the current context after a Pandemic of dramatic proportions and two wars with unknown repercussions.

"""

# ╔═╡ a6b6892e-c679-46e8-8553-65a3055fb472
md"""
!!! tip "Answer (c)"

	Rules are rules: they should be used with knowledge and wisdom. Without them, a central bank may look like a ship in the open ocean without a destination. However, applying them literally shows a total lack of wisdom because the economy may be confronted by different shocks, some of which are entirely unexpected in their impacts and nature. Central banks of the advanced economies face an extraordinarily negative situation, which requires extraordinary measures, not easy to accommodate in a rule designed to deal with "normal" times. So, rules are necessary, but they should be used with care.

"""

# ╔═╡ 8493e2d6-7a73-4616-aa0b-11d7c8109c23
md"""
## Exercise 3. The trouble with inflation
"""

# ╔═╡ b3f2f75f-ad9a-4e58-bb03-74de28379dbf
md"""

The figure below shows the main contributors to inflation in October 2022 in the USA. The inflation rate for all items was 0.4% between October and September 2022. This monthly inflation rate would correspond to annual inflation of 4.9% if the same 0.4% were verified in all following months $((1+0.004)^{12} -1 = 0.049)$. In September, the monthly inflation rate between August and September 2022 was 0.6%, leading to an annual inflation rate of 7.44%.

👉 a) If this trend continues over time, what does it tell us about the behavior of inflation?

👉 b) Looking at the various items in the figure below, what items mainly contributed to the inflation rate in October 2022?

👉 c) Can the Fed do anything to control the prices of those items most responsible for the October inflation?

"""

# ╔═╡ 348c030b-fd65-446c-8620-20a3f561aa81
Resource("https://vivaldomendes.org/images/depot/CPI_October2022.png", :width=>600)

# ╔═╡ afa3ef46-b642-4f62-a1ca-31c4a456cb2b
md"""
!!! tip "Answer (a)"

	If that trend continues, it tells us that inflation was coming down (annually) in that period.

"""

# ╔═╡ 470ad9b2-d7be-41f6-9008-49fc4a245b06
md"""
!!! tip "Answer (b)"

	The two main items that displayed a huge price increase in October were Fuel oil and Gasoline (all types). Fuel oil will affect transportation costs because almost all shipping consumes this fuel. Gasoline is the most significant energy used by everyday transportation, affecting all aspects of life. 

	So, if the prices of these two types of combustion items were going down to acceptable levels, overall inflation would also go down. The problem is that these prices are set in international markets, and it is unclear what individual economies can do about it.

"""

# ╔═╡ fb512cbd-9754-488b-89b7-91ef84dc350c
md"""
!!! tip "Answer (c)"

	No, the Fed can do very little to influence the increase in Gasoline and Fuel oil prices. The Fed can reduce aggregate demand by increasing nominal interest rates and, by doing so, can reduce the demand for those items. However, the prices of oil are highly determined by a cartel (OPEC+). Therefore, the power of the Fed is quite limited in this case.

"""

# ╔═╡ b08087c8-3d3a-4531-917a-35ff7027d06b
md"""
## Exercise 4. Inflation and the Scariest Opinion of 2022
"""

# ╔═╡ 5a6ce46e-6109-42af-9563-1447e92a86fa
md"""

In the Wall Street Journal, Sept. 7, 2022, Jason Furman -- a Professor at Harvard University and a former Chair of the Council of Economic Advisers of President Barack Obama -- published an Op-Ed. that ran with the title **_"Inflation and the Scariest Economics Paper of 2022"_**. The scariest paper can be found [here](https://www.brookings.edu/wp-content/uploads/2022/09/BPEA-FA22_WEB_Ball_Leigh_Mishra_updated.pdf) and was written by two IMF economists and Larry Ball from John Hopkins University. The principal message from this paper was:

>*"To bring price increases down to 2%, we may need to tolerate unemployment of 6.5% for two years."*

Earlier, on June 20 of the same year, another highly respected economist, Larry Summers, made the same point even more forcefully in a speech in London:

>*"We need five years of unemployment above 5% to contain inflation -- in other words, we need two years of 7.5% unemployment, or five years of 6% unemployment, or one year of 10% unemployment."* 	[Bloomberg](https://www.bloomberg.com/news/articles/2022-06-20/summers-says-us-needs-5-jobless-rate-for-five-years-to-ease-cpi?sref=qzusa8bC\#xj4y7vzkg)

Considering the evolution of inflation and unemployment in the US economy that is depicted in the figure below, answer the following questions:

👉 a) why do you think economists and policymakers were so worried about inflation in the middle of 2022?

👉 b) Why did highly respected economists get it so wrong when prescribing a particular solution
to the problem of inflation in the US?

👉 c) They based their prescriptions on one fundamental diagnosis: rampant inflation resulted from a "too hot" labor market. What alternative force may explain such explosive inflation if the labor market were not "too hot"?

"""

# ╔═╡ 5197f443-f1b9-4a0f-a64e-6c78cebe09c3
md"""
!!! tip "Answer (a)"

	In the summer of 2022, inflation in the US had reached a value close to 9%, something not seen since 1980. Economists and policymakers feared that the Fed (and the Government) would be unable to contain inflation. If inflation continued to increase even further than that, inflationary expectations would set in, and the wild 1970s would be back to haunt us with unmanageable inflation.

"""

# ╔═╡ 7c31d1f7-7c30-4727-afce-16b7bd84275e
md"""
!!! tip "Answer (b)"

	Those influential economists got it wrong because their argument was refuted by evidence: inflation has come down systematically over the last year (last September was at 3.7%), and unemployment has come down as well (not gone up to 10% as advocated by Summers). They prescribed the wrong solution to the problem of explosive inflation because they assumed that inflationary pressures came from a too-low unemployment rate (the labor market was "too hot," they argued). They made a wrong diagnosis of the problem under consideration, which explains their mistake.


"""

# ╔═╡ 72851987-a10f-4080-8cef-8277165aad53
md"""
!!! tip "Answer (c)"

	It was effortless to see that what was causing inflation was a tremendous increase in oil prices, not a hot labor market. In fact, to refute their argument, it takes a simple number: when inflation started to increase, the unemployment rate was 14.7%. How can such labor market conditions lead to a surge in inflation? It is irrational from an economic point of view, at least in our societies.

	The two cross-plots above (inflation versus unemployment and inflation versus oil prices) clearly show that inflation was caused by increases in oil prices, not by a too-hot labor market.

"""

# ╔═╡ 73ccae06-2006-4f2f-b110-fe34d082f677
md"""
## Exercise 5. Abenomics and Japanese deflation
"""

# ╔═╡ 21817ce6-ccc3-46a1-9ee5-2f7309caf596
md"""
In the following figure, we present Japan's inflation and unemployment evolution over the last four decades. Discounting the period of Abenomics -- Shinzo Abe was the prime minister between 2013 and 2020 and was elected on the promise that he would take "all necessary and sufficient" measures to ensure the country would eradicate deflation -- Japan was stuck in deflation since the summer of 1998.   

👉 a) Considering its target inflation rate of 2%, how frequently did Japan reach such a target since 1998-M07?

👉 b) In normal conditions, if an economy suffers from very low inflation, it will experience high unemployment rates. This relationship is what the Phillips curve tells us. Can we observe this situation in Japan since 1998-M07?

👉 c) The unemployment rate in Japan is very low indeed. It is implausible that this rate can go lower than 2% or 3%. This information tells us something about Potential GDP. What is it? 

👉 d) Someone asks you to create a slogan to describe the Japanese experience above. What would you propose?
"""

# ╔═╡ e2bb5f70-3e6c-4693-819e-b536af22a883
md"""
!!! tip "Answer (a)"

	Very rarely. Discounting the Abenomics period, only during four months (June to September 2008) did Japan live with 2% or higher inflation. 

"""

# ╔═╡ 1a4d2d63-b945-4861-bb56-c09aae400762
md"""
!!! tip "Answer (b)"

	No, we can not observe such a relationship for Japan since 1998-M07. The Japanese economy has experienced very low unemployment during long deflationary periods.  

"""

# ╔═╡ 46f43c27-7aba-4964-a7c4-f326dcbf951f
md"""
!!! tip "Answer (c)"

	It tells us that real GDP must be close to the Potential GDP. If real GDP were much lower than Potential GDP, the unemployment rate had to be much higher than 3%, the rate it is experiencing now.

"""

# ╔═╡ d727d33c-9f15-46d6-8518-017ef36b6cf8
md"""
!!! tip "One possible answer (d)"

	"Living at potential, addicted to deflation"

"""

# ╔═╡ 5d0cee9b-73c6-4b7e-bb0f-6773be82f845
md"""
## Exercise 6. The Zero Lower Bound
"""

# ╔═╡ c7da461d-1fc4-463e-bd46-900df67d1e03
md"""

Consider the four fundamental functions that allow us to analyze the entire functioning of the economy:

$$\begin{align*}
\text{AD}: \quad Y &=m \cdot \overline{A}-m \cdot \phi \cdot(\overline{r}+\lambda \pi) \\[3mm]           
\text{AS}: \quad  \pi &=\pi^{e}+\gamma\left(Y-Y^{P}\right)+\rho \\[3mm]  
\text{MP}: \quad r&=\overline{r}+\lambda \pi \\[3mm]  
\text{Fisher Eq.}: \quad i& =r +\pi
\end{align*}$$

and the following information concerning exogenous variables and parameters:

$$\begin{aligned}
&\overline{A}=7.6 \ , \ m=2.0 \ , \ \phi=0.2 \ , \ \overline{r}=2.0 \ , \ \lambda=0.5 \ , \ \pi^{e}=2.0 \ , \ \gamma= 4.5 \ , \ Y^{P}=14.0 \ , \ \rho=0.
\end{aligned}$$

👉 a) Calculate the short-run equilibrium values for the inflation rate, the level of GDP, the real interest rate, and the nominal interest rate. The graphical representation of this equilibrium is displayed in Fig. 4 and 5.

👉 b) Calculate the inflation rate value that corresponds to the ZLB (Zero Lower Bound).

👉 c) In Fig. 6 and 7, we represent the equilibrium associated with the AS/AD curves graphically (including the part related to the ZLB), and we do the same for the MP curve. Is the equilibrium in the ZLB?

"""

# ╔═╡ 642d0c56-56e2-48d3-ba43-cc09e0f1f7c3
md"""
!!! note
	Note that the $\left\{\pi^{e}, \overline{r}, r, i, \rho \right\}$ are rates and are measured in percentage points (e.g., $2.0$ means $2.0\%$), while $\{Y, Y^P , \overline{A}\}$ are measured in trillion dollars. In the solutions below, to avoid doubt, we put the symbol % only at the final step of the solutions.

	This exercise is a continuation of Exercise 5 of the previous weeks by adding a new ingredient: the Zero Lower Bound (ZLB) on interest rates. The solution will follow the same steps, but it will have to calculate the value of inflation that corresponds to the ZLB.

	Before we answer the questions above, we have yo pass the information about parameters and exogenous variables into the notebook:
"""

# ╔═╡ a77a222e-aba3-4ac6-a5b0-a7551e3ccce4
begin
		
	Ā3 = 7.6 ; λ3 = 0.5 ; m3 = 2.0 ; ϕ3 = 0.2;	r̄3 = 2.0 		# Demand-side parameters and exogenous variables	
			
	γ3 = 4.5 ; Yᴾ3 = 14.0 ;	πᵉ3 = 2.0 ;	ρ3 = 0.0 				# Supply-side parameters and exogenous variables
	
end;

# ╔═╡ 5cabdd52-eda2-4415-a650-76345ade196c
md"""
---
"""

# ╔═╡ d8c97fcb-7edc-4384-8da1-8b3f4b2ef471
md"""
#### Solution using NLsolve
"""

# ╔═╡ 29089f61-955b-4f02-97a1-9e49ec796e96
begin
	function my_model10_3!(F, v)									# we name our model as model10_3
	
        π = v[1] 													# variable 1 is π
        Y = v[2] 													# variable 2 is Y
		r = v[3] 													# variable 3 is r
		i = v[4] 													# variable 4 is i
				
        F[1] = m3 * Ā3 - m3 * ϕ3 * (r̄3 + λ3 * π) - Y 				# AD curve = 0	
        F[2] = πᵉ3 + γ3 * (Y - Yᴾ3) - π                 			# AS curve = 0
		F[3] = r̄3 + λ3 * π - r                     					# MP curve = 0 
		F[4] = π + r - i                                            # Fisher equation = 0             
	end
end;

# ╔═╡ ae6e7a3f-4d2b-417f-aa66-af24a5803896
begin
	solution10_3 = nlsolve(my_model10_3!, [0.0; 0.0; 0.0; 0.0])
	solution10_3.zero
end

# ╔═╡ 6fe378c7-4970-4d12-8106-2ffcba89537d
md"""
!!! tip "Answer (a)"

	We can summarize the initial equilibrium of the economy at **point 1**:

	$$Y_1=Y^{P}=14 \ \ , \ \pi_1=2 \% \ \ , \ \ r_1=2 \% \ \ , \ \ i_1=5 \%.$$
	

"""

# ╔═╡ e52f724e-4530-4221-92ff-9f558d120db7
md"""
!!! hint

	
	The rate of inflation that corresponds to the ZLB is easy to obtain. We just have to recall that

	$$\pi_{_{ZL}}=-\frac{\overline{r}}{1+\lambda}$$

"""

# ╔═╡ 34adc2d7-d7a6-4f62-b151-c71eff996074
md"""
!!! tip "Answer (b)"

	As we know that

	$$\pi_{_{ZL}}=-\frac{\overline{r}}{1+\lambda}$$

	so (see cell below):

	$$\pi_{_{ZL}}=-1.333.$$

"""

# ╔═╡ 5652b23c-c152-4a8b-ac7d-b33d782c0800
π_ZL3= - r̄3 / (1+λ3)

# ╔═╡ a006eac2-59aa-43c1-b30a-8f7c2391ef27
md"""
!!! tip "Answer (c)"

	The equilibrium is not in the ZLB because the level of inflation is 2%, which is higher than the level of inflation that corresponds to the ZLB:

	$$\pi_{_{ZL}}=-1.333\%.$$

"""

# ╔═╡ c38dbe18-a85a-4960-9c99-674196e0526d
md"""
## Exercise 7. A negative demand shock
"""

# ╔═╡ cb0d6593-5ca4-4afd-bddc-88506c4cf477
md"""

Consider the same values as in exercise $6$. However, there is an external shock that affects the Autonomous Demand, which decreases $\overline{A}$ by \$0.2 trillion. 

👉 a) The short-run equilibrium values for the inflation rate, the level of GDP, and the real interest rate are represented in Figs 8 and 9. What is the level of the nominal interest rate in this equilibrium?

👉 b) Is the economy in a recession, or in an economic boom? Justify.

👉 c) If there is no other demand or supply shock what will happen to the economy over time?

👉 d) What will be the new value of the long-run equilibrium inflation rate? What about the real and nominal interest rates?

"""

# ╔═╡ afcdf0e6-4563-4bbb-a2db-6aa6c2d07b42
md"""
!!! tip "Answer (a)"

	At point 2, we can summarize the new equilibrium of the economy by:

	$$Y^{P} \neq Y_2 =13.7895 \ , \ \pi_2=1.05263 \% \ , \ r_2=2.5263 \% \ , \ i_2=3.5789 \%.$$

	So the level of the nominal interest rate in this equilibrium is $i_2=3.5789 \%.$

"""

# ╔═╡ 3e0f6675-3586-4f9f-8cec-cf87acae58f6
md"""
!!! tip "Answer (b)"

	The economy moved from point 1 to point 2, and is now in recession, as $Y^P=14>Y_2=13.78$.

"""

# ╔═╡ 46fae038-8319-4f88-b554-600ef7c762c8
md"""
!!! tip "Answer (c)"

	The new equilibrium at point 2 is not a long-term equilibrium because the current level of GDP is below the Potential GDP. So the economy is in a recession, and inflation will gradually come down by the self-correcting market mechanism. This gradual process shifts the AS curve to the right until it reaches the vertical curve (Potential GDP). This process leads to point 3 (in the following figure), which is both a short and long-term equilibrium, *as long as the central bank accepts this new inflation rate as the new target level for such rate*. 

	There is still one crucial point. If the central bank does not accept a reduction in $\pi^T$ to $0$%, it should have reacted with a more aggressive monetary policy at point 2. If the central bank had reduced the interest rate by far more than -0.474% (from 3% to 2.526%), the AD curve would have shifted to the right, and the initial shock could have been neutralized. Notice that if the central bank had chosen a more aggressive monetary policy, the MP function would have shifted to the left.

"""

# ╔═╡ a39f29be-6494-44fc-a230-334aa552110f
md"""
!!! note
	To answer question (d), we have to represent this new equilibrium graphically by using the slider `self_correction7`. By how much will inflation decline such that the new AS function will cross the $Y^P$ curve at $0$%? A quick inspection of the plots above will tell us that the self-correcting mechanism will force inflation to go down by 2 percentage points. We can call this mechanism by "self_correction". 
"""

# ╔═╡ f11cdd5e-8b8f-47c6-bebd-a2a4ee067a3a
md"""
`self_correction7 = `$(@bind self_correction7 Slider(-3.0:0.5:3.0, default=0.0, show_value=true))
"""

# ╔═╡ d9c4f0f6-f54e-4bd8-ba73-0797fbd23dde
md"""
!!! tip "Answer (d)"

	The new long term equilibrium at point 3 will be characterized by:

	$$Y^{P} = Y_3 =14.0 \ , \ \pi_3=0 \% \ , \ r_3=2.0 \% \ , \ i_3=2.0 \%.$$

"""

# ╔═╡ aaa32024-887e-4dd2-81d6-c2b4f34db10f
md"""
## Exercise 8. Stuck in deflation
"""

# ╔═╡ 83eea9d2-0468-4d29-b780-fb0935cd9e03
md"""

Consider an economy that, for some reason, finds itself in an equilibrium inside the ZLB zone, as in point $1zl$ in the figure below. Suppose there are no more shocks on the demand or supply sides. 

👉 a) Is $1_{{ZL}}$ an equilibrium point for this economy?

👉 b) Using the slider `self_correction8` and the figure below, show the long-term equilibrium in this economy.

👉 c) Can you propose one policy measure to help this economy escape the deflation trap at point 2zl?

"""

# ╔═╡ 44a72782-4589-43db-81c1-0e88e0e20ae0
md"""
`self_correction8 = `$(@bind self_correction8 Slider(-2.0:0.1:2.0, default=0.0, show_value=true))
"""

# ╔═╡ 7a77fb62-270d-4447-8f14-c8788f540d6a
md"""
!!! tip "Answer (a)"

	The point 1zl is a short-term equilibrium for this economy, with $Y = 13.4$ trillion dollars and $\pi = 2\%$.

"""

# ╔═╡ ec202b59-9547-4565-ae95-42a4db603afa
md"""
!!! tip "Answer (b)"

	At point 1zl the economy is in a deep recession: $Y<Y^P$, which will force inflation to decrease. If inflation goes down, this will be represented by the AS curve shifting downwards (or to the right). This shift will only stop when the AS curve crosses the ADzl curve at point 2zl. This point represents the long-term equilibrium in this economy.

"""

# ╔═╡ bc4b3b16-a96c-4758-bda9-36ea1dee0555
md"""
!!! tip "Answer (c)"

	The only policy measures that can force the economy to move out of the ZLB are either (i) a large increase in public spending $($an increase in $G)$, or (ii) a large reduction in nominal interest rates $(i)$, so that aggregate demand will increase so much that the new AD curve will cross the AS curve above the ZLB.

"""

# ╔═╡ add07024-b7eb-445d-b4f4-6a6757c2ecd3
md"""
## Exercise 9. Secular stagnation
"""

# ╔═╡ 7f67d656-bb55-4097-ba49-10140f9b3502
md"""

Consider that initially, the economy is at point 1 in the figure below but suffers a huge negative external shock on aggregate demand:  $\Delta \overline{A} = -0.5$ trillion dollars. The impact of this shock can be seen in the movement of the economy to point 2 below. If the economy is at point 2, what will happen to it over time? Answer this question by maniputaing the slider `self_correction9` below.

"""

# ╔═╡ 9fb4d93f-ef2f-41a3-8c87-05f4210f6e9d
#savefig(p10_57, "SecStag.pdf", width=800, height=400, scale=1.2)

# ╔═╡ bdea4838-cbd9-4947-bc74-b351658952c1
md"""
!!! answer

	The AD negative shock drove the economy from point 1 to point 2. The economy is in a large recession because GDP (13.472 trillion dollars) is much smaller than Potential GDP (14 trillion dollars). 
	
	How will the economy move out of this big recession?  By the self-correcting mechanism, inflation will have to come down because we are in a recession. Therefore, the AS curve will move down but has to stop when it reaches the kink of the AD curve. *This is point 3 in the figure above*. The reason for the AS curve to stop at the kink is simple: if firms supply more goods & services than 13.472 trillion dollars, there will be no demand for them, so they have to stop the aggregate level of production at point 3. 
	
	This situation is described in the literature as the **"secular stagnation"** case. The term "secular" is meant to represent "for a long period". The only way out of this conundrum is if the government significantly increases public spending or if the central bank implements unconventional monetary policy (remember, at the ZLB, the nominal interest rate is already $0$%). Obviously, if a sizeable positive shock occurs (in the AD or the AS functions), the economy may also be able to return to the level of potential GDP. However, it is better to have public institutions acting than expecting some luck from unknown and uncertain exogenous forces.

"""

# ╔═╡ dcd13560-0f73-4aaa-b59a-b7961d8cdc63
md"""
## Exercise 10. Normalizing things in Japan?
"""

# ╔═╡ bdd43163-6d69-41e5-a418-5535665ccab3
md"""

Kazuo Ueda, the Governor of the Central Bank of Japan, in an recent interview with the Financial Times (November 9, [here](https://www.ft.com/content/9df570d8-a71c-48d5-95ad-98c689a87c69) ) said the following :

>“ *When we normalize short-term interest rates, we will have to be careful about what will happen to financial institutions, what will happen to borrowers of money in general, and what will happen to aggregate demand. It is going to be a serious challenge for us.”*

Why do you think it is so difficult for the Bank of Japan to raise ("normalize") short-term interest rates, given that they are negative as we can observe in the figure below?


"""

# ╔═╡ 81719a42-3d77-492b-a458-3132bab152a7
md"""
!!! tip "Answer (a)"

	The reason seems to be related to the fact that the Japanese economy has been flirting with deflation for a huge period: since 1998. Long periods of deflation have been interrupted by short spells of positive inflation rates, to succumb again to deflationary periods (as we saw in Exercise 5). If the Bank of Japan raises short-term rates above zero percent now, there is a danger that the economy may fall into deflation again. 

	Therefore, the Governor prefers to move cautiously, wait, and see what happens to aggregate demand before "normalizing" interest rates.

"""

# ╔═╡ aea60f3f-5c01-497f-8d24-fd4d1ffefbca
md"""
## Exercise 11. Deflation trap: the good & the bad equilibrium ⛔
"""

# ╔═╡ a425ba3b-c991-4b41-8570-7f70c56ef812
md"""
!!! note

	This exercise is a complex one (it is hard to solve). For this reason, it is not compulsory. Read this exercise only if you like macroeconomics a lot and want to move to a more demanding level in this field. 

"""

# ╔═╡ 82a2c755-960e-4eb7-a55a-e333eb85fa5f
md"""
Consider the data from Exercise 6. However, due to the falling oil prices in international markets, supply suffers a positive shock of $\Delta \rho = -2.0$. Simultaneously, inflation expectations fall by 2 percentage points; the new value for inflation expectations is $\pi^e=0\%$. These impacts can be seen in the figure below. What will happen to the economy if there is no active fiscal policy?
"""

# ╔═╡ 4ac136d2-0413-4b4d-a990-9bf2a49ad482
ρ6 = -2.0 ;	πᵉ6 = 0.0;

# ╔═╡ 5ce15489-49a3-4942-b3dc-15a7629169c6
md"""
#### Solution
"""

# ╔═╡ 292b1c34-b9d5-4468-98a9-4ee7a85d865b
md"""
A positive supply shock of -2 $(\rho=-2.0)$, with a simultaneous decline in inflation expectations by 2 percentage points $(\pi^e=0\%)$, moved the economy out of point 1. The economy will end up either in point 2 or in point 2zl. The *economic fundamentals* are still there: (i) there is a new AS curve which supplies a certain level of goods & services at a lower level of inflation than before those two events occurred; (ii) the AD curve is the same as before. Why do we have two different short-term macroeconomic equilibria? Because people may behave in strange ways, not easily explained by the "economic fundamentals". 

Suppose most people **believe** that the two exogenous factors will make the economy fall to a significant recession and deflation. In that case, these self-fulfilling prophecies will force the economy to move to point 2zl. At this point, the economy is in recession and, by the market self-correcting mechanism, inflation will have to come down, forcing the AS curve to move to the right until it reaches point 3. This point is a short-term and long-term equilibrium point, which means that the economy will be in a deflationary situation if nothing else happens.  What may take the economy out of this situation if no other shock occurs? The usual tools culprits will do: a significant expansionary fiscal policy or a non-conventional monetary policy.

On the other hand, if most people are not too worried about the negative impact of those two factors, this attitude will have a positive effect on economic activity, and the economy will jump into point 2. Notice that there is nothing terribly wrong with having lower oil prices, neither with private agents formulating lower inflation expectations. What happens is that aggregate demand will increase if inflation goes down, and so will also GDP.  Point 2 is a short-term equilibrium but not a long-term one. As we are in an economic boom, inflation will have to increase due to the market self-correcting mechanism, and the AS curve will move up until it reaches point 1.  This point is both a short-run and a long-run macroeconomic equilibrium. In this case, we do not need an active fiscal policy to deal with the long-run disequilibrium in point 2. A conventional monetary policy has to accommodate the gradual increase in inflation while the economy moves from point 2 to point 1.

In macroeconomics, this situation of having the same economic fundamentals and two different long-term macroeconomic equilibria is normally denominated by "self-fulfilling prophecies", "sunspots", or "indeterminacy". As Isaac Newton once put it: *"I can calculate the motion of heavenly bodies, but not the madness of people"*. The madness of people may prevail everywhere, even in macroeconomics.
"""

# ╔═╡ 26fe310e-9ed8-4d09-bb82-a5bd39193dde
md"""
# Reality Check
"""

# ╔═╡ 63e8392d-c2b3-4a1a-b9f1-2acffe23ecb4
md"""
## Application 1

### An important speech by Jerome Powell, Fed's Chair 
"""

# ╔═╡ 3bed5d29-9973-4990-961a-53e53451854e
md"""

*"Inflation that runs below its desired level can lead to an unwelcome fall in longer-term inflation expectations, which, in turn, can pull actual inflation even lower, resulting in an adverse cycle of ever-lower inflation and inflation expectation.* 

*This dynamic is a problem because expected inflation feeds directly into the general level of interest rates. Well-anchored inflation expectations are critical for giving the Fed the latitude to support employment when necessary without destabilizing inflation. But if inflation expectations fall below our 2 percent objective, interest rates would decline in tandem. In turn, we would have less scope to cut interest rates to boost employment during an economic downturn, further diminishing our capacity to stabilize the economy through cutting interest rates. We have seen this adverse dynamic play out in other major economies around the world and have learned that once it sets in, it can be very difficult to overcome. We want to do what we can to prevent such a dynamic from happening here.” (page 8/9)*

[Jerome Powel (2020)](https://www.federalreserve.gov/newsevents/speech/files/powell20200827a.pdf) *New Economic Challenges and the Fed’s Monetary Policy Review*, speech at the Conference  “Navigating the Decade Ahead:  Implications for Monetary Policy,” symposium sponsored by the Federal Reserve Bank of Kansas City, August 27, 2020. 

Do you see any connection between what we discussed during this week and the great concerns of the President (Chair) of the Federal Reserve Board of the USA in his most relevant speech in 2020? Do you think that the problems of deflation and lower inflation expectations are irrelevant issues in modern macroeconomics?

"""

# ╔═╡ 9c5a5fcc-4655-4250-9214-1e819a862fa5
md"""
	!!! hint

		This speech touches on all major points covered this week: the fear of deflation, the importance of inflation expectations, the relevance of having a 2% target interest rate, and a responsible central should do all it takes to prevent deflation from setting in.


	"""

# ╔═╡ 8bfbcdd2-66b4-4884-8edd-71d3d8416a21
md"""
## Application 2

### Ignore Japan at your peril 
"""

# ╔═╡ ad3c4297-138f-4bdd-b839-e85ead198ee7
md"""
It is incredible how a developed, democratic and open society felt into the deflation trap since June 1998, even though successive governments and central bank's presidents tried to avoid such a situation. The central bank of Japan has an inflation target of 2%, as most developed economies. But since mid 1998, only in 12 out of the 264 months were Japan capable of achieving such a target. In fact, most of the time, Japan has experienced quite severe deflation (-1%, -2%, and even -2.5%), some of them for extended periods. Surprisingly, *despite significant deflation, the Japanese economy has displayed relatively low unemployment rates*. 

Can we explain this Japanese case with our model? And with our exercises above? Yes, Exercise 8 can easily explain the Japanese case. Why has Japan not been able to escape from the long-term equilibrium inside the ZLB? Some influencial economists have argued that in the past -- before 2013, when Prime Minister Shinzo Abe came to power and nominated a new Governor of the Central Bank of Japan -- Japanese governments and the central bank did not take the necessary measures to avoid the economy diving into the deflationary trap. They only took timid measures to deal with an exceptional danger, and the trap settled in. The positive impact on inflation of the measures taken by prime minister Shinzo Abe and his appointed Bank of Japan Governor (Haruhiko Kuroda) after 2013 can be easily seen in the figure above. Since 2013, the number of months with positive inflation is much greater than the number of those with deflation: a very different picture from what had happened before. 
"""

# ╔═╡ 1503e906-0783-407d-a3f7-134d3c99c766
md"""
# Auxiliary cells (do not delete)
"""

# ╔═╡ 9fa87191-7c90-4738-a45a-acd929c8bd1b
  TableOfContents()

# ╔═╡ 7d88deaf-f6c6-4ca3-a098-88d47d4e9b80
begin
      struct TwoColumns{L, R}
    left::L
    right::R
      end
      
      function Base.show(io, mime::MIME"text/html", tc::TwoColumns)
          write(io, """<div style="display: flex;"><div style="flex: 48%;margin-right:2%;">""")
          show(io, mime, tc.left)
          write(io, """</div><div style="flex: 48%;">""")
          show(io, mime, tc.right)
          write(io, """</div></div>""")
      end
end

# ╔═╡ 9ea169aa-0760-4051-8772-2873544c714e
TwoColumns(
md"""

`ΔĀ9 = `$(@bind ΔĀ9 Slider(-1.0:0.1:1.0, default=-0.5, show_value=true))

""",
	
md"""

`self_correction9 = `$(@bind self_correction9 Slider(-3.0:0.1:3.0, default=0.0, show_value=true))

"""
)

# ╔═╡ 56fe63eb-96fb-4dc9-ab4c-802ccb5e18a5
md"### CSS code"

# ╔═╡ 82ccd7d9-2f97-4439-af15-0087392913e6
html"""
<style>
	@media screen {
		main {
			margin: 0 auto;
			max-width: 1700px;
    		padding-left: max(100px, 10%);
    		padding-right: max(380px, 10%); 
            # 383px to accommodate TableOfContents(aside=true)
		}
	}
</style>
"""

# ╔═╡ 99e824b2-e12c-4090-87cb-45b3d042ee79
md"""
!!! note "Target inflation rate across the world"

	| Central Bank        | Target          |    | Central Bank          | Target
	| :---------------    | ------------:   |:---| :---------------      | -------:
	| US                  | 2               |    | New Zealand           | 2,$\pm$ 1
	| Japan               | 2               |    |Australia 		    | [2-3] 
	| EuroZone            | 2               |    |Canada                | 2,$\pm$ 1
	| UK                  | 2               |    |Switzerland           | <2
	| Sweden              | 2               |    |China		 			| 3
	| Norway              | 2               |    |Mexico 			 	| 3,$\pm$ 1

""";

# ╔═╡ 916b9c85-e357-4d10-bba1-2b641a4dbc28
md"""
#### Exercise 1. Supporting cells (Inflation targetting)
"""

# ╔═╡ 3d73b76d-59e2-4249-9034-f9bbb2a1074b
period10_1 = MonthlyDate(1997,1):Month(1):MonthlyDate(2021,6);

# ╔═╡ b6f5869c-62af-4e81-ae73-912fe522896e
EZ_Inf = CSV.read("EZ_inflation.csv", delim=';', DataFrame);

# ╔═╡ 99fc937d-f798-418a-a57f-5ddc3feb5f3e
begin
	trace10_1 = scatter(;x = Date.(period10_1), y = EZ_Inf[:,2], 
				name = "EuroZone", mode="markers+lines",
				marker_symbol="circle", marker_size="4.5",line_width= 0.3, 
            	marker_color = "DarkRed")
	
	trace10_2 = scatter(;x = Date.(period10_1), y = EZ_Inf[:,3], 
				name = "Portugal", mode="markers+lines",
				marker_symbol="circle", marker_size="4.5",line_width= 0.3,
            	marker_color = "Blue")

	layout10_2 = Layout(;

			annotations=[  attr(x="2015-09-01", y=2.05,
           					text="Target inflation rate (2%)",
							font=attr(
                					family="Calibri",
                					size=15,
                					color="black" ),
							ax=0, ay=-120,
            				showarrow=true,
            				arrowhead=3)],
			
		
			title_text = "Fig 1. Inflation in the EuroZone and Portugal", title_x=0.5,
		
			hovermode="x",		
		
            xaxis = attr(
               title = "Monthly obervations",
               #tickformat = "%Y",
              # hoverformat = "%Y-M%m",
               tick0 = "1997/01/01",
               #dtick = "M60" 
			),
		
        	xaxis_range = ["1996-09-01" , "2021-10-01"],
        	yaxis_title = "Percentage points",
        	#yaxis_range=[-2, 2], 
        	titlefont_size = 16)

	p10_2 = Plot([trace10_1, trace10_2], layout10_2)
	add_shape!(p10_2, line( x0="1996-09-01", y0=2.0, x1="2021-10-01", y1=2.0 , line=attr(color="RoyalBlue", width=2.5)))
	p10_2
end

# ╔═╡ dde94490-9fdd-4417-90ae-0a6735eb505a
Loss = EZ_Inf[:,2:3].-2;

# ╔═╡ 2dce7165-029d-43cc-8358-9a8df3f86d2a
Loss2 =sqrt.((EZ_Inf[:,2:3].-2).^2);

# ╔═╡ 475d7d83-5f9c-4fed-a6dc-31a46678d6bf
Loss2a = abs.((EZ_Inf[:,2:3].-2));

# ╔═╡ 5811e2cb-4448-4b03-a812-ab284b583c86
begin
	#Loss1 = mapcols(t -> ifelse.(t .< 0, 0, t), Loss)
	Loss1 = ifelse.(Loss .< 0, 0, Loss)
	#Loss1 = clamp.(Loss, 0.0, Inf)
end;

# ╔═╡ f6081970-7d0e-4aba-b712-bca0a06d4319
describe(Loss1, :mean, :min, :median, :max, :std);

# ╔═╡ 8362fd70-ae19-45f8-bb6d-386946cd793c
describe(Loss2, :mean, :min, :median, :max , :std);

# ╔═╡ 8e2f6e74-d1e3-46fd-842d-bce5bcf08713
describe(Loss2a, :mean, :min, :median, :max , :std);

# ╔═╡ edf08bd1-dcd2-4129-a61f-c1e4f6bb09d9
begin
	trace10_5 = scatter(;x = Date.(period10_1), y =Loss1[:,1], 
				name = "EuroZone", mode="markers+lines",
				marker_symbol="circle", marker_size="4.5",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "Red")
	
	trace10_6 = scatter(;x = Date.(period10_1), y = Loss1[:,2], 
				name = "Portugal", mode="markers+lines",
				marker_symbol="circle", marker_size="4.5",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "Blue")

	layout10_6 = Layout(;
		
			title_text = "Fig 2. Positive Deviations from Target",
			title_x = 0.5,
			hovermode="x",
		
            xaxis = attr(
               title = "Monthly observations",
               tickformat = "%Y",
               hoverformat = "%Y-M%m",
               tick0 = "1997/01/01",
               dtick = "M60" ),
		
        	xaxis_range = ["1996-09-01" , "2021-10-01"],
        	yaxis_title = "Percentage points",
        	yaxis_range=[0,4], 
        	titlefont_size = 16)

	p10_6 = Plot([trace10_5, trace10_6], layout10_6)
end;

# ╔═╡ 0b858694-3d54-4f05-8132-9bfcd302534a
begin
	trace10_7 = scatter(;x = Date.(period10_1), y =Loss2[:,1], 
				name = "EuroZone", mode="markers+lines",
				marker_symbol="circle", marker_size="4.5",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "Red")
	
	trace10_8 = scatter(;x = Date.(period10_1), y = Loss2[:,2], 
				name = "Portugal", mode="markers+lines",
				marker_symbol="circle", marker_size="4.5",line_width= 0.3, 
            	#marker_color="LightSteelBlue", 
				marker_color = "Blue" )

	layout10_8 = Layout(;
		
			title_text = "Fig 3. Positive & Negative Deviations from Target",
			title_x = 0.5,
			
			hovermode="x",
		
            xaxis = attr(
               title = "Monthly observations",
               tickformat = "%Y",
               hoverformat = "%Y-M%m",
               tick0 = "1997/01/01",
               dtick = "M60" ),
		
        	xaxis_range = ["1996-09-01" , "2021-10-01"],
        	yaxis_title = "Percentage points",
        	yaxis_range=[0,4], 
        	titlefont_size = 16)


	p10_8 = Plot([trace10_7, trace10_8], layout10_8)
end;

# ╔═╡ 9446db0c-db46-4d42-beca-55f152f0e8f5
begin
p10_9 = [p10_6  p10_8]
end

# ╔═╡ a94575d7-81e5-4929-b9df-c423016e865c

let
	p = make_subplots(rows=2, cols=2,
    specs=[Spec(colspan=2) missing ; Spec() Spec()],
            subplot_titles=["1. Inflation in the EuroZone and Portugal"  "3. Positive & negative deviations from 				target" ; " 2. Positive deviations from target" missing],
            vertical_spacing = 0.1, horizontal_spacing = 0.09 )

    add_trace!(p, trace10_1, row=1, col=1)
    add_trace!(p, trace10_2, row=1, col=1)
    add_trace!(p, trace10_5, row=2, col=1)    
    add_trace!(p, trace10_6, row=2, col=1)
    add_trace!(p, trace10_7, row=2, col=2)
    add_trace!(p, trace10_8, row=2, col=2)

    relayout!(p, showlegend=true, title_text = "Central bank losses",
            height = "800", xaxis_range = ["1996-09-01", "2021-09-01"], hovermode = "x" )
    p
end;



# ╔═╡ 242f70a8-bc87-4dfc-8d14-bc8861c5148a
begin
	trace10_7a = scatter(;x = Date.(period10_1), y =Loss2a[:,1], 
				name = "EuroZone", mode="markers+lines",
				marker_symbol="circle", marker_size="4",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "Red")
	
	trace10_8a = scatter(;x = Date.(period10_1), y = Loss2a[:,2], 
				name = "Portugal", mode="markers+lines",
				marker_symbol="circle", marker_size="4",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "Blue")

	layout10_8a = Layout(;
		
			title_text = "Fig 3. Positive & Negative Deviations from Target",
			title_x = 0.5,
			
			hovermode="x",
		
            xaxis = attr(
               title = "Monthly observations",
               tickformat = "%Y",
               hoverformat = "%Y-M%m",
               tick0 = "1997/01/01",
               dtick = "M60" ),
		
        	xaxis_range = ["1996-09-01" , "2021-10-01"],
        	yaxis_title = "Percentage points",
        	yaxis_range=[0,4], 
        	titlefont_size = 16)


	p10_8a = Plot([trace10_7a, trace10_8a], layout10_8a)
end;

# ╔═╡ c9942e2d-318d-48b8-b145-96425791cae5
begin
	trace10_3 = scatter(;x = Date.(period10_1), y =Loss[:,1], 
				name = "EuroZone", mode="markers+lines",
				marker_symbol="circle", marker_size="4",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "Blue")
	
	trace10_4 = scatter(;x = Date.(period10_1), y = Loss[:,2], 
				name = "Portugal", mode="markers+lines",
				marker_symbol="circle", marker_size="4",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "Red")

	layout10_4 = Layout(;
		
			title_text = "Inflation in the EuroZone and Portugal: Deviations from Target", title_x=0.5,
		
			hovermode="x",
		
            xaxis = attr(
               title = "Monthly obervations",
               tickformat = "%Y",
               hoverformat = "%Y-M%m",
               tick0 = "1997/01/01",
               dtick = "M60" ),
		
        	#xaxis_range = [2000, 2020],
        	yaxis_title = "Percentage points",
        	#yaxis_range=[-2, 2], 
        	titlefont_size = 16)

	p10_4 = Plot([trace10_3, trace10_4], layout10_4)
end;

# ╔═╡ 056d9341-78f1-4cb1-8a8e-a71ff246cf9d
md"""
#### Exercise 2. Supporting cells (Taylor rule)
"""

# ╔═╡ da6d64b3-cea6-42b4-9270-97e5df74c5cf
period10_2 = QuarterlyDate(1960, 1):Quarter(1):QuarterlyDate(2022,4);

# ╔═╡ d61ba2bc-fb1e-4e00-afff-192a493a1956
let
	fig= Plot(Layout(Subplots(rows=2, cols=1, 
			subplot_titles=	["Textbook rule versus the Federal Funds Rate" "Textbook rule minus the Federal Funds Rate" ], 
			vertical_spacing=0.1, horizontal_spacing = 0.09)))
	
	add_trace!(fig, scatter(;x = Date.(period10_2), y = (Taylor_textbook), mode="markers+lines", marker_size = 4.5, line_width= 0.3, marker_color = "Purple", name = "Textbook Rule"),   row=1, col=1)
	
	add_trace!(fig, scatter(;x = Date.(period10_2), y = i, name = "FFR"), row=1, col=1)

	add_trace!(fig, bar(;x = Date.(period10_2), y = (Taylor_textbook .- i), mode="markers+lines", line_width= 0.3, marker_color = "darkblue", name = ""),  row=2, col=1)
	
	relayout!(fig, hovermode="x", height = 700, legend_orientation="h", legend=attr( x=0.65, y=0.97), xaxis_range = [Date.(1960), Date.(2023)],)
	
	PlutoPlotly.plot(fig) # This need to be the `plot` function from PlutoPlotly, not from PlotlyJS
end

# ╔═╡ 89565b78-3ce4-4f0e-9ee2-0d563d7f9e68
let
	fig= Plot(Layout(Subplots(rows=2, cols=1, 
			subplot_titles=	["Taylor rule versus the Federal Funds Rate" "Taylor rule minus the Federal Funds Rate" ], 
			vertical_spacing=0.1, horizontal_spacing = 0.09)))
	
	add_trace!(fig, scatter(;x = Date.(period10_2), y = (Taylor_standard), mode="markers+lines", marker_size = 4.5, line_width= 0.3, marker_color = "Purple", name = "Taylor Rule"),   row=1, col=1)
	
	add_trace!(fig, scatter(;x = Date.(period10_2), y = i, name = "FFR"), row=1, col=1)

	add_trace!(fig, bar(;x = Date.(period10_2), y = (Taylor_standard .- i), mode="markers+lines", line_width= 0.3, marker_color = "darkblue", name = ""),  row=2, col=1)
	
	relayout!(fig, hovermode="x", height = 700, legend_orientation="h", legend=attr( x=0.65, y=0.97), xaxis_range = [Date.(1960), Date.(2023)],)
	
	PlutoPlotly.plot(fig) # This need to be the `plot` function from PlutoPlotly, not from PlotlyJS
end

# ╔═╡ a7b2ef76-4626-4e89-9c78-98fa286923b3
let
	fig= Plot(Layout(Subplots(rows=2, cols=1, 
			subplot_titles=	["New Taylor rule versus the Federal Funds Rate" "New Taylor rule minus the Federal Funds Rate" ], 
			vertical_spacing=0.1, horizontal_spacing = 0.09)))
	
	add_trace!(fig, scatter(;x = Date.(period10_2), y = (Taylor_new), mode="markers+lines", marker_size = 4.5, line_width= 0.3, marker_color = "blue", name = "New Taylor Rule"),   row=1, col=1)
	
	add_trace!(fig, scatter(;x = Date.(period10_2), y = i, name = "FFR"), row=1, col=1)

	add_trace!(fig, bar(;x = Date.(period10_2), y = (Taylor_new .- i), mode="markers+lines", line_width= 0.3, marker_color = "darkred", name = ""),  row=2, col=1)
	
	relayout!(fig, hovermode="x", height = 700, legend_orientation="h", legend=attr( x=0.65, y=0.97), xaxis_range = [Date.(1960), Date.(2023)],)
	
	PlutoPlotly.plot(fig) # This need to be the `plot` function from PlutoPlotly, not from PlotlyJS
end

# ╔═╡ 2275faad-ae60-49b6-a2e9-eda7a806b134
begin
	trace10_10 = scatter(;x = Date.(period10_2), y = Taylor_textbook, 
				name = "Textbook Rule", mode="markers+lines",
				marker_symbol="circle", marker_size="4.5",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "Blue")
	
	trace10_11 = scatter(;x = Date.(period10_2), y = i, 
				name = "FFR", mode="lines",
				marker_symbol="circle", marker_size="0.0",line_width= 1.5, 
            	#marker_color="LightSteelBlue",
            	marker_color = "Red")

		
	layout10_11 = Layout(;
				legend=attr( x=0.8, y=0.95),
		
				title_text = "The textbook rule (USA: 1960.Q1--2022.Q3)", title_x = 0.5,
		
				hovermode="x",		
		
            	xaxis = attr(
                title = "Quarterly obervations",
                tickformat = "%Y",
                hoverformat = "%Y-Q%q",
                #tick0 = "1960/04/01",
                #dtick = "M120",
        				),
        		xaxis_range = [Date.(1959), Date.(2023)],
        		yaxis_title = "Percentage points",
        		#yaxis_range=[-2, 2], 
        		titlefont_size = 16)
	
	

	p10_11 = Plot([trace10_10, trace10_11], layout10_11)
end;

# ╔═╡ d7e4c204-d21d-4119-a26f-124cf6ec5fa5
begin
	trace10_12 = scatter(;x = Date.(period10_2), y = Taylor_standard, 
				name = "Taylor Rule", mode="markers+lines",
				marker_symbol="circle", marker_size="4.5",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "Blue")
	
	trace10_13 = scatter(;x = Date.(period10_2), y = i, 
				name = "FFR", mode="markers+lines",
				marker_symbol="circle", marker_size="4.5",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "Red")

		
	layout10_13 = Layout(;
	
				legend=attr( x=0.8, y=0.95),
				title_text = "The Taylor Rule: Standard Version (USA: 1960.Q1--2022.Q4)", title_x =0.5,
		
				hovermode="x",		
		
            	xaxis = attr(
                title = "Quarterly obervations",
                tickformat = "%Y",
                hoverformat = "%Y-Q%q",
                #tick0 = "1960/01/01",
                #dtick = "M120",	),
				),
        		xaxis_range = [Date.(1959), Date.(2023)],
        		yaxis_title = "Percentage points",
        		#yaxis_range=[-2, 2], 
        		titlefont_size = 16)
	
	

	p10_13 = Plot([trace10_12, trace10_13], layout10_13)
	#savefig(p10_13,"C:\\Users\\Utilizador\\Desktop\\AAA_Aulas\\Mishkin_Julia_Files\\coco.pdf")
end;

# ╔═╡ 0ce61106-cc15-44fa-a9a6-02ae2074154a
#savefig(p10_13, "Taylor_standard.pdf", width=800, height=400, scale=10);

# ╔═╡ 6991c328-413a-4947-8542-a585e9010bca
begin
	trace10_14 = bar(;x = Date.(period10_2), y = (Taylor_standard.-i), 
				name = "Taylor Rule", mode="markers+lines",
				marker_symbol="circle", marker_size="4",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	#marker_color = "DarkBlue"
	)
	
			
	layout10_14 = Layout(; 
		
				title_text = "Taylor rule minus the Fed Funds Rate (USA: 1960.Q1--2022.Q4)", title_x =0.5,
		
				hovermode="x",
		
            	xaxis = attr(
                title = "Quarterly obervations",
                tickformat = "%Y",
                hoverformat = "%Y-Q%q",
                tick0 = "1960/01/01",
                dtick = "M120",
        				),
        		#xaxis_range = [1960, 2020],
        		yaxis_title = "Percentage points",
        		#yaxis_range=[-2, 2], 
        		titlefont_size = 16)
	
	

	p10_14 = Plot([trace10_14], layout10_14)
end;

# ╔═╡ f7404380-0681-4466-ac61-a0f1dc4b94ef
begin
	trace10_15 = scatter(;x = Date.(period10_2), y = Taylor_new, 
				name = "New Taylor Rule", mode="markers+lines",
				marker_symbol="circle", marker_size="4.5",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "DarkBlue")
	
	trace10_16 = scatter(;x = Date.(period10_2), y = i, 
				name = "FFR", mode="markers+lines",
				marker_symbol="circle", marker_size="4.5",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "Red")

		
	layout10_16 = Layout(;

				legend=attr( x=0.8, y=0.95),
	
				title_text = "New Taylor rule: more emphasis on the output gap (USA: 1960.Q1-2022.Q4)", 
				title_x =0.5,
		
				hovermode="x",	
		
            	xaxis = attr(
                title = "Quarterly observations",
                tickformat = "%Y",
                hoverformat = "%Y-Q%q",
                #tick0 = "1960/01/01",
                #dtick = "M120",
        				),
        		xaxis_range = [Date.(1959), Date.(2023)],
        		yaxis_title = "Percentage points",
        		#yaxis_range=[-2, 2], 
        		titlefont_size = 16)
	
	

	p10_16 = Plot([trace10_15, trace10_16], layout10_16)
end;

# ╔═╡ a7d4f49e-e317-44bd-bc77-a136e8182d59
#savefig(p10_16, "Taylor_new.pdf", width=800, height=400, scale=10);

# ╔═╡ 99e3138f-5fea-43e7-8f6b-195f2517c673
begin
	trace10_17 = bar(;x = Date.(period10_2), y = (Taylor_new.-i), 
				name = "Taylor Rule", mode="markers+lines",
				marker_symbol="circle", marker_size="4",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "darkred")
	
			
	layout10_17 = Layout(;
		
				title_text = "New Taylor rule minus the Federal Funds Rate (USA: 1960.Q1-2022.Q4)", title_x =0.5,
		
				hovermode="x",
		
            	xaxis = attr(
                title = "Quarterly obervations",
                tickformat = "%Y",
                hoverformat = "%Y-Q%q",
                tick0 = "1960/01/01",
                dtick = "M120",
        				),
        		#xaxis_range = [1960, 2020],
        		yaxis_title = "Percentage points",
        		#yaxis_range=[-2, 2], 
        		titlefont_size = 16)

	p10_17 = Plot([trace10_17], layout10_17)
end;

# ╔═╡ c5e17c57-eb95-45de-aece-2493260cce7b
md"""
#### Exercise 4. Supporting cells (Scary paper)
"""

# ╔═╡ 1b801b74-99bf-4f0e-ac9e-b0da33341f1b
scary = CSV.read("Scary_Paper.csv", DataFrame);

# ╔═╡ 25de8e33-de65-40b0-98d5-bdf7563910af
period4_1 = MonthlyDate(2016,1): Month(1): MonthlyDate(2023,9);

# ╔═╡ 53a03fb0-5e1b-450c-b720-2c71765f4154
begin
	scary1=Plot(
    [
        scatter(x=Date.(period4_1), y=scary.CPI[313:end] , name="CPI", line_color="Red"),
		scatter(x=Date.(period4_1), y=scary.UR[313:end] , name="UR", line_color="Gray"),
        scatter(x=Date.(period4_1), y= scary.Oil[313:end], name="Oil", yaxis="y2", line_color="Blue")
    ],
    Layout(
        title_text="The Scary Paper and Some Data", title_x=0.5,
        #xaxis_title_text="xaxis title",
        yaxis_title_text="Percentage values",
		legend=attr( x=0.05, y=0.95),
        yaxis2=attr(
            title="Dollars per barrel",
            overlaying="y",
            side="right",
			showgrid = false
        )
    )
)
	relayout!(scary1, hovermode="x", height = 400, legend_orientation="h", xaxis_range = ["2015-12-01", "2023-10-01"])
	scary1
end

# ╔═╡ 6376af97-b159-4365-8928-93c596f7b3d7
begin
	scary2= Plot(Layout(Subplots(rows=1, cols=2, 
			#specs=[Spec() Spec(); Spec(colspan=2) missing],
    		subplot_titles=["Inflation vs Unemployment"  "Inflation vs Oil prices"] ,
			vertical_spacing = 0.1, horizontal_spacing = 0.09)))
	
	add_trace!(scary2, scatter(;x = scary.UR[313:end], y = scary.CPI[313:end], mode="markers+lines", marker_size = 5.5, line_width= 0.3, marker_color = "blue", name = ""), row=1, col=1)
	

	add_trace!(scary2, scatter(;x = scary.Oil[313:end], y = scary.CPI[313:end], mode="markers+lines", marker_size = 5.5, line_width= 0.3, marker_color = "darkred", name = ""),  row=1, col=2)

	
	relayout!(scary2, hovermode="", height = 400, legend_orientation="h", showlegend=false)
	
	scary3 = PlutoPlotly.plot(scary2) # This need to be the `plot` function from PlutoPlotly, not from PlotlyJS
end;

# ╔═╡ 18685b35-d444-4a29-9947-9d244b02f241
p40=Plot(scatter(;x = scary.UR[313:end], y = scary.CPI[313:end], mode="markers+lines", marker_size = 5.5, line_width= 0.3, marker_color = "blue", name = ""), Layout(;title_text = "Inflation vs Unemployment", title_x = 0.5, xaxis_title = "Unemployment rate", yaxis_title = "Inflation rate "));

# ╔═╡ 15499265-1c43-486b-a9d7-dadb8a522bd2
p41=Plot(scatter(;x = scary.Oil[313:end], y = scary.CPI[313:end], mode="markers+lines", marker_size = 5.5, line_width= 0.3, marker_color = "darkred", name = ""), Layout(;title_text = "Inflation vs Oil prices", title_x = 0.5, xaxis_title = "Oil prices (dollars per barrel)", yaxis_title = "Inflation rate"));

# ╔═╡ 255fdba7-664d-4826-9280-7830dec5e74e
begin
	p42 = [p40 p41]
	relayout!(p42, height = 400)
	p42
end

# ╔═╡ 8600ed97-f3d4-4c63-985a-ebd7ce7d5d55


# ╔═╡ 7c7af504-8508-40f9-a47d-b4518c2f4079
md"""
#### Exercise 5. Supporting cells (Abenomics)
"""

# ╔═╡ 9f0b3172-d9cd-4275-8b20-cb42e988cc0f
#Japan= CSV.read("Japan_Deflation.csv", delim=';', DataFrame)

# ╔═╡ 9b3eab00-1c20-4caa-9232-fa2d1ce0a31d
Japan2 = CSV.read("Japan_Deflation_V1.csv", DataFrame);

# ╔═╡ e96bccd3-554e-44b6-89f4-def910aac29a
period10_9 = MonthlyDate(1991, 1):Month(1):MonthlyDate(2021,9);

# ╔═╡ 288a991b-ea0e-4994-ae0c-db8ecfd94d08
let
	
	trace10_80 = scatter(;x = Date.(period10_9), y = Japan2[:,2], 
				mode="markers+lines", name  = "UR",
				marker_symbol="circle", marker_size="1",line_width= 2, 
            	#marker_color="LightSteelBlue",
            	marker_color = "Blue")
	
	trace10_81 = bar(;x = Date.(period10_9), y = Japan2[:,3], 
				mode="markers+lines", name  = "CPI", 
				marker_symbol="circle", marker_size="4",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "DarkBlue")
	

	layout10_81 = Layout(;
		
		title_text = "Inflation (CPI) and Unemployment (UR) Rates in Japan: 1991-2021", title_x =0.5,
		
		hovermode="x",
		
		
        xaxis = attr(
               title = "Monthly observations", 
               tickformat = "%Y",
               hoverformat = "%Y-M%m",
               tick0 = "1997/10/01",
               dtick = "M36"),
		
        #xaxis_range = [Date.(1990), Date.(2022)],
		xaxis_range=["1990-09-01", "2021-12-31"],
        yaxis_title = "Percentage points",
        #yaxis_range=[-2, 2], 
        titlefont_size = 16)

	p10_82 = Plot([trace10_80, trace10_81], layout10_81)
	add_shape!(p10_82, line( x0="1998-07-01", y0=-3, x1="1998-07-01", y1=6 , line=attr(color="Darkorange", width=2)))
	relayout!(p10_82, annotations=[attr(x="1998-07-01", y=6,
            text="1998-M07",
            showarrow=false,
            yshift=10), (x="2016-09-01", y=6,
            text="Shinzo Abe as prime-minister",
            showarrow=false,
            yshift=10)]
				)
	add_vrect!(p10_82, "2012-12-01", "2020-09-01",  fillcolor = "red", opacity = 0.2, line_width = 0; row=1, col=1)
	p10_82
end

# ╔═╡ 0d216aac-314a-4ff0-9b31-f2f1e850655f
let
	
	trace10_80 = scatter(;x = Date.(period10_9), y = Japan2[:,2], 
				mode="markers+lines", name  = "UR",
				marker_symbol="circle", marker_size="1",line_width= 2, 
            	#marker_color="LightSteelBlue",
            	marker_color = "Blue")
	
	trace10_81 = bar(;x = Date.(period10_9), y = Japan2[:,3], 
				mode="markers+lines", name  = "CPI", 
				marker_symbol="circle", marker_size="4",line_width= 0.3, 
            	#marker_color="LightSteelBlue",
            	marker_color = "DarkBlue")
	

	layout10_81 = Layout(;
		
		title_text = "Inflation (CPI) and Unemployment (UR) Rates in Japan: 1991-2021", title_x =0.5,
		
		hovermode="x",
		
		
        xaxis = attr(
               title = "Monthly observations", 
               tickformat = "%Y",
               hoverformat = "%Y-M%m",
               tick0 = "1997/10/01",
               dtick = "M36"),
		
        #xaxis_range = [Date.(1990), Date.(2022)],
		xaxis_range=["1990-09-01", "2021-12-31"],
        yaxis_title = "Percentage points",
        #yaxis_range=[-2, 2], 
        titlefont_size = 16)

	p10_82 = Plot([trace10_80, trace10_81], layout10_81)
	add_shape!(p10_82, line( x0="1998-07-01", y0=-3, x1="1998-07-01", y1=6 , line=attr(color="Darkorange", width=2)))
	relayout!(p10_82, annotations=[attr(x="1998-07-01", y=6,
            text="1998-M07",
            showarrow=false,
            yshift=10), (x="2016-09-01", y=6,
            text="Shinzo Abe as prime-minister",
            showarrow=false,
            yshift=10)]
				)
	add_vrect!(p10_82, "2012-12-01", "2020-09-01",  fillcolor = "red", opacity = 0.2, line_width = 0; row=1, col=1)
	p10_82
end

# ╔═╡ a9818a71-fc9c-483a-9482-2f062232e73d
#period10_8 = MonthlyDate(1997,10):Month(1):MonthlyDate(2021,5);

# ╔═╡ c44af435-f632-4542-b914-fe83dcde78a5
md"""
#### Exercise 6. Supporting cells (ZLB)
"""

# ╔═╡ a3b3c4ab-2d3d-4511-b3dd-36e0ec273cb0
begin
	πd_max3 = (Ā3 / (λ3 * ϕ3)) - r̄3/λ3 									# The AD curve y-axis' intercept 
	
	πs_min3 = πᵉ3 - γ3 * Yᴾ3 + ρ3 									# The AS curve y-axis' intercept
end;

# ╔═╡ e3be2df9-6d5f-4541-ba35-ec65ebfeb4c3
begin
	Y3 = 12.0:0.01:15.0
	
	πd3 = πd_max3 .- ((1 ./(m3 .* ϕ3 .* λ3)) .* Y3) 
	πs3 = πs_min3 .+ γ3 .*Y3             
	
	trace10_20 = scatter(; x = [14,14] , y = [-8,14] , mode = "line", 
		line_width = "4", name = "Yp", line_color = "Orange")
	
	trace10_21 = scatter(; x = Y3, y = πd3, mode="lines" , 
		line_color = "Blue", line_width = "3", name = "AD")
	
	trace10_22 = scatter(; x = Y3, y = πs3, mode="lines" , 
		line_color = "Red", line_width = "3", name  = "AS")
	
	trace10_23 = scatter(; x = [14.0], y = [2.0], text =["1"], 
		textposition = "top center", name = "Eq1", mode = "markers+text", 
		marker_size = "11", marker_color = "Blue", 
		textfont = attr(family="sans serif", size=18, color="black"))
	
	
	layout10_23 = Layout(;
		title_text ="Fig 5. Macroeconomic Equilibrium",
		title_x = 0.5,
		hovermode = "x",
        xaxis = attr(title=" GDP trillion dollars (Y)", 
			showgrid=true, zeroline=false),
        xaxis_range = [13.5, 14.5],	
        yaxis = attr(title="Rate of inflation (π)", zeroline = false),
		yaxis_range = [-0 , 5])

   p10_23 = Plot([trace10_20, trace10_21, trace10_22, trace10_23], layout10_23)
	
end;

# ╔═╡ cc0f9f16-fd0b-4024-9fe7-744294d744c3
begin
	r3 = 0.0:0.001:5.0
	
	πmp3 = - (r̄3 ./ λ3) .+  r3 ./ λ3 
	
	trace4_0 = scatter(; x = r3, y = πmp3, mode = "lines", line_color = "Brown", 
		line_width = "3", name  = "MP")
	
	trace4_1 = scatter(; x = [3.0], y = [2.0], text =["1"], 
		textposition = "top center", name ="Eq1", mode="markers+text", 
		marker_size = "11",	marker_color = "Brown",
		textfont = attr(family="sans serif", size=18, color="black") )
	
	layout4_1 = Layout(;
		title_text ="Fig 4. MP Curve",
		title_x = 0.5,
		hovermode = "x",
        xaxis = attr(title=" Real interest rate (r)", showgrid=true, 
			zeroline=false),
        xaxis_range = [2.0, 4.5],
		xaxis_tickvals = [2, 2.5, 3, 3.5, 4, 4.5],
        yaxis = attr(title="Rate of inflation (π)", zeroline = false),
		yaxis_range = [-0 , 5])

   p4_1 = Plot([trace4_0, trace4_1], layout4_1)
end;

# ╔═╡ 5eb27597-8fcf-4f35-8a49-818bdbce8951
begin
	p4_2 =[p4_1 p10_23]
end

# ╔═╡ 1385bba0-7daf-4fe6-a9f8-9cc2fa29e600
begin
	Y_ZL3 = Ā3 * m3 - (m3 *  ϕ3 * r̄3) / (1+λ3)
	πd_min3 = - Ā3 / ϕ3
end;

# ╔═╡ 9b5ac60d-6732-4636-a2b2-08ab6f7297ad
begin
	Y3_ZL = 11 : 0.001 : Y_ZL3

	πd3_normal = πd_max3 .- (1 ./(m3 .* ϕ3 .* λ3)) .* Y3_ZL
	
	πd3_ZL = πd_min3 .+ (1 ./(m3 .* ϕ3)) .* Y3_ZL

	trace10_24 = scatter(; x = Y3_ZL , y = πd3_normal , mode = "line", name ="AD", line_color = "Blue")
	
	trace10_25 = scatter(; x = Y3_ZL , y = πd3_ZL , mode = "line", name ="ADzl", line_color = "BlueViolet")


	trace10_26 = scatter(; x = [11.9, 15.1] , y = [π_ZL3 , π_ZL3] , line_dash="dashdot", 
		line_width = "0.5", name = "ZLB", line_color = "black")

		
	layout10_26 = Layout(
					title_text = "Fig 7. The AD/AS Curves with a ZLB",
					title_x = 0.5,
					hovermode = "x",
					xaxis_title = "GDP trillion dollars (Y)",
					xaxis_range = [13 , 15],
					yaxis_range=[-6 ,8],
					yaxis_title = "Rate of inflation (π)",
					#yaxis_range=[-1 ,5], 
					)

	p10_27 = Plot([trace10_24, trace10_25, trace10_26], layout10_26)
	p10_28 = addtraces(p10_27, trace10_20, trace10_22, trace10_23) # trace2 is the AS function
end;

# ╔═╡ 4b401a4a-65ee-494e-8587-eb94d38668cb
let
	Y3 = 12.5:0.001:15.0
	πs_min6 = πᵉ6 - γ3 * Yᴾ3 + ρ6
	πs6 = πs_min6 .+ γ3 .*Y3 
	
	trace10_61 = scatter(; x = Y3, y = πs6 .+ 1.1 , mode="lines" , line_color = "Red", 
		line_width = "3", name  = "AS")
	
	trace10_62 = scatter(; x = [13.4], y = [-3.6], text =["1zl"], textposition = "top center", 
		name = "Eq1", mode = "markers+text", marker_size = "11", marker_color = "Blue",
		textfont = attr(family="sans serif", size=16, color="black"))
	
	trace10_64 = scatter(; x = [14.0], y = [-2.0], text =["2zl"], textposition = "bottom center", 
		name = "Eq2", mode = "markers+text", marker_size = "11", marker_color = "Blue",
		textfont = attr(family="sans serif", size=18, color="black"))

	trace10_65 = scatter(; x = Y3_ZL , y = πd3_ZL .* 1.065 .+ 1.19 , mode = "line", name ="ADzl", line_color = "BlueViolet", line_width = "3")

	trace10_66 = scatter(; x = Y3, y = πs6 .+ 1.1 .+ self_correction8, mode="lines" , line_color = "Red", 
		line_width = "3", name  = "AS2")
	
	
	layout10_61 = Layout(
					title_text = "Stuck in deflation",
					title_x = 0.5,
					hovermode = "x",
					xaxis_title = "GDP trillion dollars (Y)",
					xaxis_range = [13.0 , 14.4],
					yaxis_range=[-5.5 , 0.0],
					yaxis_title = "Rate of inflation (% points)",
					#yaxis_range=[-1 ,5], 
					)
	
	p10_61 = Plot([trace10_61], layout10_61)
	p10_62 = addtraces(p10_61, trace10_66, trace10_65, trace10_26, trace10_20, 
		 trace10_62, trace10_64) 
	#	trace10_23, trace10_53, trace10_56) 
	#savefig(p10_62, "stuckZLB.pdf", width=800, height=400, scale=1.5)
end

# ╔═╡ 3bc3f9b4-c716-4655-a3cd-e83efbdbf4b9
begin
	πs_min6 = πᵉ6 - γ3 * Yᴾ3 + ρ6
	πs6 = πs_min6 .+ γ3 .*Y3 
	
	trace10_61 = scatter(; x = Y3, y = πs6, mode="lines" , line_color = "Red", 
		line_width = "3", name  = "AS")
	
	trace10_62 = scatter(; x = [13.5], y = [-4.25], text =["2zl"], textposition = "top center", 
		name = "Eq2zl", mode = "markers+text", marker_size = "11", marker_color = "Blue",
		textfont = attr(family="sans serif", size=16, color="black"))
	
	trace10_63 = scatter(; x = [14.4211], y = [-0.105263], text =["2"], textposition = "top center", 
		name = "Eq2", mode = "markers+text", marker_size = "11", marker_color = "Blue",
		textfont = attr(family="sans serif", size=16, color="black"))
	
	trace10_64 = scatter(; x = [14.0], y = [-3.0], text =["3"], textposition = "bottom center", 
		name = "Eq3", mode = "markers+text", marker_size = "11", marker_color = "Blue",
		textfont = attr(family="sans serif", size=18, color="black"))
	
	
	layout10_61 = Layout(
					title_text = "Deflation trap: the good & the bad equilibrium",
					title_x = 0.5,
					hovermode = "x",
					xaxis_title = "GDP trillion dollars (Y)",
					xaxis_range = [13 , 15],
					yaxis_range=[-7 , 8],
					yaxis_title = "Rate of inflation (% points)",
					#yaxis_range=[-1 ,5], 
					)
	
	p10_61 = Plot([trace10_61], layout10_61)
	p10_62 = addtraces(p10_61, trace10_22, trace10_24, trace10_25, trace10_26, trace10_20, trace10_23, 
		trace10_63, trace10_62, trace10_64) 
	#	trace10_23, trace10_53, trace10_56) 
end

# ╔═╡ ecd1d9df-bec2-4d67-850b-1c263bfe2606
begin
	
	r3_ZL = -π_ZL3 : 0.001 : 5

	# Defining the two branches 

	πmp3_normal = -(r̄3 ./ λ3) .+  r3_ZL ./ λ3

	πmp3_ZL = -r3_ZL


	# Defining each of the functions we want to plot in each trace1

	trace10_30 = scatter(; x = r3_ZL , y = πmp3_normal , mode = "line", name ="MP", line_color = "Brown")
	
	trace10_31 = scatter(; x = r3_ZL , y = πmp3_ZL , mode = "line", name ="MPzl", 
		line_color = "Chocolate")

	trace10_32 = scatter(; x = [0.9 , 5.1] , y = [π_ZL3 , π_ZL3] , line_dash="dashdot", 
		line_width = "0.5", name = "ZLB", line_color = "black")


	trace10_33 = scatter(; x = [3], y = [2], text =["1"], textposition = "top center", 
					   name ="Eq1", mode="markers+text", marker_size= "11", marker_color="Brown",
					   textfont = attr(family="sans serif", size=18, color="black"))


	# The layout chosen

	layout10_33 = Layout(
					title_text = "Fig 6. The MP Curve with a ZLB",
					title_x = 0.5,
					hovermode = "x",
					xaxis_title = "Real interest rate (% points)",
					xaxis_range = [1, 5],
					yaxis_range=[-6 , 8],
					yaxis_title = "Rate of inflation (π)",
					#yaxis_range=[-1 ,5], 
					)

	# Plotting

	p10_33 = Plot([trace10_30, trace10_31, trace10_32, trace10_33], layout10_33)
end;

# ╔═╡ b2071081-ad56-43a8-8bf4-54802bfbc739
begin
	p10_34 =[p10_33  p10_28]
end

# ╔═╡ 1684b665-eae3-4e96-9f10-5909e09d9964
md"""
#### Exercise 7. Supporting cells (Negative demand shock)
"""

# ╔═╡ 2a8b4884-a1e7-4803-a2b1-6ce85955de93
begin	
	ΔĀ4 = -0.2 															# the shock to the AD function
	Y_ZL3_ΔAbar4 = (Ā3 + ΔĀ4) * m3 - (m3 *  ϕ3 * r̄3) / (1+λ3)
	πd_min4 = - (Ā3 + ΔĀ4 ) / ϕ3
	πd_max4 = (Ā3 + ΔĀ4)  / (λ3 * ϕ3) - r̄3/λ3 							# The AD curve y-axis' intercept	
end;

# ╔═╡ dad66466-0f3f-4908-92a4-50c5b20e5be5
begin
	function my_model10_4!(F, v)
	
           	π = v[1]
           	Y = v[2]
		   	r = v[3]
			i = v[4]
				
           	F[1] = π + (1/(m3 * ϕ3 * λ3))*Y - πd_max4     	# AD curve = 0
           	F[2] = π - γ3 * Y - πs_min3                   	# AS curve = 0
			F[3] = λ3 * π - r + r̄3                     		# MP curve = 0 
			F[4] = i - π - r                               	# Fisher Equation = 0
	end
end;

# ╔═╡ 6ac7c37a-96a5-49d8-8fff-b76e381b6367
begin
	solution10_4 = nlsolve(my_model10_4!, [0.0; 0.0; 0.0; 0.0])
	solution10_4.zero
end;

# ╔═╡ f5fde724-21f9-4184-a317-8dfe75ec84ba
begin
	Y4_ZL = 12 : 0.0001 : Y_ZL3_ΔAbar4

	πd4_normal = πd_max4 .- (1 ./(m3 .* ϕ3 .* λ3)) .* Y4_ZL
	
	πd4_ZL = πd_min4 .+ (1 ./(m3 .* ϕ3)) .* Y4_ZL

	trace10_35 = scatter(; x = Y4_ZL , y = πd4_normal , mode = "line", name ="AD", line_color = "Blue")
	
	trace10_36 = scatter(; x = Y4_ZL , y = πd4_ZL  , mode = "line", name ="ADzl", line_color = "BlueViolet")
	
	trace10_37 = scatter(; x = [11.0, 15.1] , y = [π_ZL3 , π_ZL3] , line_dash="dashdot", 
		line_width = "0.5", name = "ZLB", line_color = "black")
	
	trace10_38 = scatter(; x = [13.7895], y = [1.05263], text =["2"], textposition = "top center", 
		name = "Eq2", mode = "markers+text", marker_size = "11", marker_color = "Blue",
		textfont = attr(family="sans serif", size=16, color="black"))
		
	layout10_38 = Layout(
					title_text = "Fig 9. The AD/AS Curves with a ZLB",
					title_x = 0.5,
					hovermode = "x",
					xaxis_title = "GDP trillion dollars (Y)",
					xaxis_range = [13.25 , 14.5],
					yaxis_range=[-4 ,4],
					yaxis_title = "Rate of inflation (% points)",
					#yaxis_range=[-1 ,5], 
					)

	p10_36 = Plot([trace10_35, trace10_36, trace10_37], layout10_38)
	p10_37 = addtraces(p10_36, trace10_20, trace10_22, trace10_23, trace10_38) # trace2 is the AS function
end;

# ╔═╡ e00c9d65-074e-4cb3-8e08-b32a58ee92c4
begin
	
	trace10_39 = scatter(; x = [2.52631], y = [1.05263], text =["2"], textposition = "top center", 
					   name ="Eq2", mode="markers+text", marker_size= "11", marker_color="Brown",
					   textfont = attr(family="sans serif", size=16, color="black"))
	
	layout10_39 = Layout(
					title_text = "Fig 8. The MP Curve with a ZLB",
					title_x = 0.5,
					hovermode = "x",
					xaxis_title = "Real interest rate (% points)",
					xaxis_range = [1, 4],
					yaxis_range=[-4 , 4],
					yaxis_title = "Rate of inflation (% points)",
					#yaxis_range=[-1 ,5], 
					)

	p10_39 = Plot([trace10_39 , trace10_33], layout10_39)
	p10_40 = addtraces(p10_39, trace10_30, trace10_31, trace10_32)
end;

# ╔═╡ 495cbcdb-4120-4200-bfa6-5d1ad59308bb
begin
	p10_41 =[p10_40  p10_37]
end

# ╔═╡ 1e98e928-68bd-4102-bdc8-2536b4615eaa
begin

	trace10_42 = scatter(; x = Y3, y = πs3 .+ self_correction7, mode="lines" , 
		line_color = "DarkRed", line_width = "3", name  = "AS2")
	
	trace10_43 = scatter(; x = [14.0], y = [0.0], text =["3"], textposition = "top center", 
		name = "Eq3", mode = "markers+text", marker_size = "12", marker_color = "Blue",
		textfont = attr(family="sans serif", size=18, color="black"))
	

	p10_43 = Plot([trace10_20, trace10_22, trace10_42], layout10_38)
	p10_44 = addtraces(p10_43, trace10_35, trace10_36, trace10_37,  
		trace10_23, trace10_38, trace10_43) # trace10_20 is the YP function
end;

# ╔═╡ 1d7292a7-0dc6-4c0a-8e3c-fce761f3c499
begin
	
	trace10_45 = scatter(; x = [2], y = [0], text =["3"], textposition = "top center", 
					   name ="Eq3", mode="markers+text", marker_size= "10", marker_color="Brown",
					   textfont = attr(family="sans serif", size=16, color="black"))
	
	p10_45 = Plot([trace10_33, trace10_39, trace10_45], layout10_39)
	p10_46 = addtraces(p10_45, trace10_30, trace10_31, trace10_32)
end;

# ╔═╡ 5499984f-c56d-4a84-aa6b-24d48ec3b786
begin
	p10_47 =[p10_46  p10_44]
end

# ╔═╡ eeeb30c0-6b7d-42ff-93b8-dd647d72babe
md"""
#### Exercise 9. Supporting cells (secular stagnation)
"""

# ╔═╡ 91fd4da1-abe0-4096-adcd-581d41fbfc33
begin	
	Y_ZL3_ΔĀ9 = (Ā3 + ΔĀ9) * m3 - (m3 *  ϕ3 * r̄3) / (1+λ3)
	πd_min5 = - (Ā3 + ΔĀ9 ) / ϕ3
	πd_max5 = (Ā3 + ΔĀ9)  / (λ3 * ϕ3) - r̄3/λ3 # The AD curve y-axis' intercept	
end;

# ╔═╡ d4c73d36-fc14-4968-9166-660e05cd2078
begin
	Y5_ZL = 11 : 0.001 : Y_ZL3_ΔĀ9

	πd5_normal = πd_max5 .- (1 ./(m3 .* ϕ3 .* λ3)) .* Y5_ZL
	
	πd5_ZL = πd_min5 .+ (1 ./(m3 .* ϕ3)) .* Y5_ZL

	trace10_50 = scatter(; x = Y5_ZL , y = πd5_normal , mode = "line", name ="AD", line_color = "Blue")
	
	trace10_51 = scatter(; x = Y5_ZL , y = πd5_ZL , mode = "line", name ="ADzl", line_color = "BlueViolet")
	
	trace10_52 = scatter(; x = [10.9, 15.1] , y = [π_ZL3 , π_ZL3] , line_dash="dashdot", 
		line_width = "0.5", name = "ZLB", line_color = "black")
	
	trace10_53 = scatter(; x = [13.4737], y = [-0.368421], text =["2"], textposition = "top center", 
		name = "Eq2", mode = "markers+text", marker_size = "11", marker_color = "Blue",
		textfont = attr(family="sans serif", size=16, color="black"))
		
	layout10_53 = Layout(
					title_text = "The AD/AS curves with a ZLB",
					title_x = 0.5,
					xaxis_title = "GDP trillion dollars (Y)",
					xaxis_range = [13 , 14.2],
					yaxis_range=[-3 , 3],
					yaxis_title = "Rate of inflation (% points)",
					#yaxis_range=[-1 ,5], 
					)

	p10_53 = Plot([trace10_50, trace10_51, trace10_52], layout10_53)
	p10_54 = addtraces(p10_53, trace10_20, trace10_22, trace10_23, trace10_53)
end;

# ╔═╡ 291adf2b-f5d7-40da-9778-f2218045273d
begin
	trace10_55 = scatter(; x = Y3, y = πs3 .+ self_correction9, mode="lines" , 
		line_color = "DarkRed", line_width = "3", name  = "AS2")
	
	trace10_56 = scatter(; x = [13.66667], y = [π_ZL3], text =["3"], textposition = "top center", 
		name = "Eq3", mode = "markers+text", marker_size = "11", marker_color = "Blue",
		textfont = attr(family="sans serif", size=18, color="black"))
	
	layout10_62 = Layout(
					title_text = "Secular stagnation",
					title_x = 0.5,
					hovermode = "x",
					xaxis_title = "GDP trillion dollars (Y)",
					xaxis_range = [13 , 14.2],
					yaxis_range=[-3 , 3],
					yaxis_title = "Rate of inflation (% points)",
					#yaxis_range=[-1 ,5], 
					)
	p10_56 = Plot([trace10_55], layout10_62)
	p10_57 = addtraces(p10_56, trace10_20, trace10_50, trace10_51, trace10_52, trace10_22, 
		trace10_23, trace10_53, trace10_56) 
end

# ╔═╡ a81ad800-8dcc-4972-8245-5edf568aa611
self_correction5 = π_ZL3 - πs_min3 - γ3 * 13.666677;

# ╔═╡ a2730369-1206-453d-930a-b6c779395cd5
begin
	function my_model10_5!(F, v)
	
           	π = v[1]
           	Y = v[2]
		   	r = v[3]
			i = v[4]
				
           	F[1] = π + (1/(m3 * ϕ3 * λ3))*Y - πd_max5     # AD function = 0
           	F[2] = π - γ3 * Y - πs_min3                   # AS function = 0
			F[3] = λ3 * π - r + r̄3                        # MP function = 0 
			F[4] = i - π - r                              # Fisher Equation = 0
	end
end

# ╔═╡ 56bf8ed2-5786-4e51-b9c8-7a68a0690283
begin
	solution10_5 = nlsolve(my_model10_5!, [0.0; 0.0; 0.0; 0.0])
	solution10_5.zero
end;

# ╔═╡ e1c5c854-02c0-439c-9ba6-3f03be2a3d61
md"""
The new equilibrium at point 2 will be characterized by:

$$Y^{P} > Y_2 =13.4737 \ , \ \pi_2=-0.368421 \% \ , \ r_2=1.81579 \% \ , \ i_2=1.44737 \%.$$
"""

# ╔═╡ f9d1d025-6b70-4a54-bc8a-7f7c5cad318a
md"""
###### Solution of point 3 using NLsolve
"""

# ╔═╡ 13f44f40-72d2-493f-a584-e17b6d0e102b
md"""
Notice that at the kink of the ZLB, the AD curve consists of just one point:
$$\pi = \pi_{ZL3}.$$
Therefore, in the NSolve system the function F[1] should be written as: F[1] = π - π_ZL3
"""

# ╔═╡ f6d599fb-ac27-4c44-972f-28f300f43cdf
begin
	function my_model10_5a!(F, v)
	
           	π = v[1]
           	Y = v[2]
		   	r = v[3]
			i = v[4]				
           	
           	F[1] = π - π_ZL3 										# AD function = 0
			F[2] = π - γ3 * Y - (πs_min3 + self_correction5)        # AS function = 0
			F[3] = λ3 * π - r + r̄3                     				# MP function = 0 
			F[4] = i - π - r                               			# Fisher Equation = 0
	end
end;

# ╔═╡ ed9a0b2a-68fb-4996-81b2-60ba59248207
begin
	solution10_5a = nlsolve(my_model10_5a!, [0.0; 0.0; 0.0; 0.0 ])
	solution10_5a.zero
end;

# ╔═╡ b1ea211b-4ab8-49bd-96b7-dd8631cb689a
md"""
The new equilibrium under secular stagnation will be characterized by:

$$Y^{P} > Y_{3} =13.6667 \ , \ \pi_{3}=-1.33333 \% \ , \ r_{3}=1.33333 \% \ , \ i_{3}=0.0 \%.$$
"""

# ╔═╡ 87ec44a5-7b4e-4dde-84f1-126fc565a0b1
md"""
#### Exercise 10. Supporting cells (Nomalizing things in Japan?)
"""

# ╔═╡ a452dd71-b0f3-4bbb-a1b5-15522a262018
night = CSV.read("Japan_Overnight.csv", DataFrame);

# ╔═╡ a5519357-d4f8-4b65-aa83-6ccdd5485b4a
period9_1 = MonthlyDate(2000, 1): Month(1): MonthlyDate(2023, 9);

# ╔═╡ 79078ac3-3955-437a-8aed-88ef606d8aca
begin
	Plot(bar(; x= Date.(period9_1),y =  night.Overnight, marker_color="Blue"), Layout(; hovermode = "x", title_text = "Japan Overnight Interest Rates: Interbank Rate (< 24 Hours)", title_x = 0.5))
end

# ╔═╡ 47ac77f3-4f6d-4469-a2b7-edf35a049ed3
md"""
#### Exercise 11. Supporting cells (Deflation trap)
"""

# ╔═╡ 51d0366d-3224-4a48-9e8e-7c8e4d41fd7e
md"""
###### Solution of point 2 using NLsolve
"""

# ╔═╡ 3a2b7a9b-0f24-4166-ba46-fc0b3df74f46
begin
	function my_model10_6!(F, v)
	
           	π = v[1]
           	Y = v[2]
		   	r = v[3]
			i = v[4]
				
           	F[1] = π + (1/(m3 * ϕ3 * λ3))*Y - πd_max3     	# AD curve = 0
           	F[2] = π - γ3 * Y - πs_min6                   	# AS curve = 0
			F[3] = λ3 * π - r + r̄3                     		# MP curve = 0 
			F[4] = i - π - r                              	# Fisher Equation = 0
	end

	solution10_6 = nlsolve(my_model10_6!, [0.0; 0.0; 0.0; 0.0])
	solution10_6.zero
end;

# ╔═╡ 9b68bbc2-d7f3-4bd7-9993-e4fe20363645


# ╔═╡ 5a8e44d3-ba71-4bb7-b6cc-509b08c9e1bb
md"""
The new equilibrium in point 2 will be characterized by:

$$Y^{P} < Y_2 =14.4211 \ , \ \pi_2=-0.105263 \% \ , \ r_2=1.94737 \% \ , \ i_2=1.84211 \%.$$
"""

# ╔═╡ 1b076f8f-f69f-40af-afe5-68749a409785
md"""
###### Solution of point 2zl using NLsolve
"""

# ╔═╡ 1dfbe74a-61d7-48d8-823b-4d19efb3e6be
md"""
Notice that the AD function in the ZLB is given by the expression:

$$Y=m \cdot \bar{A}+m \cdot \phi \cdot \pi_{Z L}$$
So the F[1] has to be rewritten in the NSolve code as: 
$\mathrm{F}[1]=\mathrm{Y}-\mathrm{m} 3 * \overline{A}3-(\mathrm{m} 3 * \phi 3) * \pi$

"""

# ╔═╡ 960c426d-e69d-46f4-bc7c-a9c921b1a257
begin
	function my_model10_6a!(F, v)
	
           	π = v[1]
           	Y = v[2]
		   	r = v[3]
			i = v[4]
				
           	F[1] = Y - m3 * Ā3 - (m3 * ϕ3)* π     	  	# AD function = 0
           	F[2] = π - γ3 * Y - πs_min6                 # AS function = 0
			F[3] = λ3 * π - r + r̄3                      # MP function = 0 
			F[4] = i - π - r                            # Fisher Equation = 0
	end
	
	solution10_6a = nlsolve(my_model10_6a!, [0.0; 0.0; 0.0; 0.0])
	solution10_6a.zero
end;

# ╔═╡ 29a9d34f-f239-43eb-9ce8-9c07c35d2d4e


# ╔═╡ 81536d10-9345-4889-b6d1-8fda40d2b0cb
md"""
The new equilibrium in point 2 will be characterized by:

$$Y^{P} > Y_{2zl} =13.5 \ , \ \pi_{2zl}=-4.25 \% \ , \ r_{2zl}=-0.125 \% \ , \ i_{2zl}=-4.375 \%.$$
"""

# ╔═╡ 00000000-0000-0000-0000-000000000001
PLUTO_PROJECT_TOML_CONTENTS = """
[deps]
CSV = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
Dates = "ade2ca70-3891-5945-98fb-dc099432e06a"
HypertextLiteral = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
NLsolve = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
PeriodicalDates = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
PlotlyBase = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
PlutoPlotly = "8e989ff0-3d88-8e9f-f020-2b208a939ff0"
PlutoUI = "7f904dfe-b85e-4ff6-b463-dae2292396a8"

[compat]
CSV = "~0.10.7"
DataFrames = "~1.4.2"
HypertextLiteral = "~0.9.5"
NLsolve = "~4.5.1"
PeriodicalDates = "~2.0.0"
PlotlyBase = "~0.8.19"
PlutoPlotly = "~0.4.6"
PlutoUI = "~0.7.48"
"""

# ╔═╡ 00000000-0000-0000-0000-000000000002
PLUTO_MANIFEST_TOML_CONTENTS = """
# This file is machine-generated - editing it directly is not advised

julia_version = "1.10.0"
manifest_format = "2.0"
project_hash = "4bb4f127032861416e5134e3740d160976e93d18"

[[deps.AbstractPlutoDingetjes]]
deps = ["Pkg"]
git-tree-sha1 = "6e1d2a35f2f90a4bc7c2ed98079b2ba09c35b83a"
uuid = "6e696c72-6542-2067-7265-42206c756150"
version = "1.3.2"

[[deps.Adapt]]
deps = ["LinearAlgebra", "Requires"]
git-tree-sha1 = "6a55b747d1812e699320963ffde36f1ebdda4099"
uuid = "79e6a3ab-5dfb-504d-930d-738a2a938a0e"
version = "4.0.4"

    [deps.Adapt.extensions]
    AdaptStaticArraysExt = "StaticArrays"

    [deps.Adapt.weakdeps]
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.ArgTools]]
uuid = "0dad84c5-d112-42e6-8d28-ef12dabb789f"
version = "1.1.1"

[[deps.ArrayInterface]]
deps = ["Adapt", "LinearAlgebra", "SparseArrays", "SuiteSparse"]
git-tree-sha1 = "133a240faec6e074e07c31ee75619c90544179cf"
uuid = "4fba245c-0d91-5ea0-9b3e-6abc04ee57a9"
version = "7.10.0"

    [deps.ArrayInterface.extensions]
    ArrayInterfaceBandedMatricesExt = "BandedMatrices"
    ArrayInterfaceBlockBandedMatricesExt = "BlockBandedMatrices"
    ArrayInterfaceCUDAExt = "CUDA"
    ArrayInterfaceCUDSSExt = "CUDSS"
    ArrayInterfaceChainRulesExt = "ChainRules"
    ArrayInterfaceGPUArraysCoreExt = "GPUArraysCore"
    ArrayInterfaceReverseDiffExt = "ReverseDiff"
    ArrayInterfaceStaticArraysCoreExt = "StaticArraysCore"
    ArrayInterfaceTrackerExt = "Tracker"

    [deps.ArrayInterface.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    CUDA = "052768ef-5323-5732-b1bb-66c8b64840ba"
    CUDSS = "45b445bb-4962-46a0-9369-b4df9d0f772e"
    ChainRules = "082447d4-558c-5d27-93f4-14fc19e9eca2"
    GPUArraysCore = "46192b85-c4d5-4398-a991-12ede77f4527"
    ReverseDiff = "37e2e3b7-166d-5795-8a7a-e32c996b4267"
    StaticArraysCore = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
    Tracker = "9f7883ad-71c0-57eb-9f7f-b5c9e6d3789c"

[[deps.Artifacts]]
uuid = "56f22d72-fd6d-98f1-02f0-08ddc0907c33"

[[deps.Base64]]
uuid = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"

[[deps.BaseDirs]]
git-tree-sha1 = "3e93fcd95fe8db4704e98dbda14453a0bfc6f6c3"
uuid = "18cc8868-cbac-4acf-b575-c8ff214dc66f"
version = "1.2.3"

[[deps.CSV]]
deps = ["CodecZlib", "Dates", "FilePathsBase", "InlineStrings", "Mmap", "Parsers", "PooledArrays", "PrecompileTools", "SentinelArrays", "Tables", "Unicode", "WeakRefStrings", "WorkerUtilities"]
git-tree-sha1 = "6c834533dc1fabd820c1db03c839bf97e45a3fab"
uuid = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
version = "0.10.14"

[[deps.CodecZlib]]
deps = ["TranscodingStreams", "Zlib_jll"]
git-tree-sha1 = "59939d8a997469ee05c4b4944560a820f9ba0d73"
uuid = "944b1d66-785c-5afd-91f1-9de20f533193"
version = "0.7.4"

[[deps.ColorSchemes]]
deps = ["ColorTypes", "ColorVectorSpace", "Colors", "FixedPointNumbers", "PrecompileTools", "Random"]
git-tree-sha1 = "67c1f244b991cad9b0aa4b7540fb758c2488b129"
uuid = "35d6a980-a343-548e-a6ea-1d62b119f2f4"
version = "3.24.0"

[[deps.ColorTypes]]
deps = ["FixedPointNumbers", "Random"]
git-tree-sha1 = "b10d0b65641d57b8b4d5e234446582de5047050d"
uuid = "3da002f7-5984-5a60-b8a6-cbb66c0b333f"
version = "0.11.5"

[[deps.ColorVectorSpace]]
deps = ["ColorTypes", "FixedPointNumbers", "LinearAlgebra", "Requires", "Statistics", "TensorCore"]
git-tree-sha1 = "a1f44953f2382ebb937d60dafbe2deea4bd23249"
uuid = "c3611d14-8923-5661-9e6a-0046d554d3a4"
version = "0.10.0"
weakdeps = ["SpecialFunctions"]

    [deps.ColorVectorSpace.extensions]
    SpecialFunctionsExt = "SpecialFunctions"

[[deps.Colors]]
deps = ["ColorTypes", "FixedPointNumbers", "Reexport"]
git-tree-sha1 = "fc08e5930ee9a4e03f84bfb5211cb54e7769758a"
uuid = "5ae59095-9a9b-59fe-a467-6f913c188581"
version = "0.12.10"

[[deps.CommonSubexpressions]]
deps = ["MacroTools", "Test"]
git-tree-sha1 = "7b8a93dba8af7e3b42fecabf646260105ac373f7"
uuid = "bbf7d656-a473-5ed7-a52c-81e309532950"
version = "0.3.0"

[[deps.Compat]]
deps = ["TOML", "UUIDs"]
git-tree-sha1 = "c955881e3c981181362ae4088b35995446298b80"
uuid = "34da2185-b29b-5c13-b0c7-acf172513d20"
version = "4.14.0"
weakdeps = ["Dates", "LinearAlgebra"]

    [deps.Compat.extensions]
    CompatLinearAlgebraExt = "LinearAlgebra"

[[deps.CompilerSupportLibraries_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "e66e0078-7015-5450-92f7-15fbd957f2ae"
version = "1.0.5+1"

[[deps.ConstructionBase]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "260fd2400ed2dab602a7c15cf10c1933c59930a2"
uuid = "187b0558-2788-49d3-abe0-74a17ed4e7c9"
version = "1.5.5"

    [deps.ConstructionBase.extensions]
    ConstructionBaseIntervalSetsExt = "IntervalSets"
    ConstructionBaseStaticArraysExt = "StaticArrays"

    [deps.ConstructionBase.weakdeps]
    IntervalSets = "8197267c-284f-5f27-9208-e0e47529a953"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Crayons]]
git-tree-sha1 = "249fe38abf76d48563e2f4556bebd215aa317e15"
uuid = "a8cc5b0e-0ffa-5ad4-8c14-923d3ee1735f"
version = "4.1.1"

[[deps.DataAPI]]
git-tree-sha1 = "abe83f3a2f1b857aac70ef8b269080af17764bbe"
uuid = "9a962f9c-6df0-11e9-0e5d-c546b8b5ee8a"
version = "1.16.0"

[[deps.DataFrames]]
deps = ["Compat", "DataAPI", "Future", "InvertedIndices", "IteratorInterfaceExtensions", "LinearAlgebra", "Markdown", "Missings", "PooledArrays", "PrettyTables", "Printf", "REPL", "Random", "Reexport", "SnoopPrecompile", "SortingAlgorithms", "Statistics", "TableTraits", "Tables", "Unicode"]
git-tree-sha1 = "d4f69885afa5e6149d0cab3818491565cf41446d"
uuid = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
version = "1.4.4"

[[deps.DataStructures]]
deps = ["Compat", "InteractiveUtils", "OrderedCollections"]
git-tree-sha1 = "1d0a14036acb104d9e89698bd408f63ab58cdc82"
uuid = "864edb3b-99cc-5e75-8d2d-829cb0a9cfe8"
version = "0.18.20"

[[deps.DataValueInterfaces]]
git-tree-sha1 = "bfc1187b79289637fa0ef6d4436ebdfe6905cbd6"
uuid = "e2d170a0-9d28-54be-80f0-106bbe20a464"
version = "1.0.0"

[[deps.Dates]]
deps = ["Printf"]
uuid = "ade2ca70-3891-5945-98fb-dc099432e06a"

[[deps.DelimitedFiles]]
deps = ["Mmap"]
git-tree-sha1 = "9e2f36d3c96a820c678f2f1f1782582fcf685bae"
uuid = "8bb1440f-4735-579b-a4ab-409b98df4dab"
version = "1.9.1"

[[deps.DiffResults]]
deps = ["StaticArraysCore"]
git-tree-sha1 = "782dd5f4561f5d267313f23853baaaa4c52ea621"
uuid = "163ba53b-c6d8-5494-b064-1a9d43ac40c5"
version = "1.1.0"

[[deps.DiffRules]]
deps = ["IrrationalConstants", "LogExpFunctions", "NaNMath", "Random", "SpecialFunctions"]
git-tree-sha1 = "23163d55f885173722d1e4cf0f6110cdbaf7e272"
uuid = "b552c78f-8df3-52c6-915a-8e097449b14b"
version = "1.15.1"

[[deps.Distances]]
deps = ["LinearAlgebra", "Statistics", "StatsAPI"]
git-tree-sha1 = "66c4c81f259586e8f002eacebc177e1fb06363b0"
uuid = "b4f34e82-e78d-54a5-968a-f98e89d6e8f7"
version = "0.10.11"

    [deps.Distances.extensions]
    DistancesChainRulesCoreExt = "ChainRulesCore"
    DistancesSparseArraysExt = "SparseArrays"

    [deps.Distances.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.Distributed]]
deps = ["Random", "Serialization", "Sockets"]
uuid = "8ba89e20-285c-5b6f-9357-94700520ee1b"

[[deps.DocStringExtensions]]
deps = ["LibGit2"]
git-tree-sha1 = "2fb1e02f2b635d0845df5d7c167fec4dd739b00d"
uuid = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
version = "0.9.3"

[[deps.Downloads]]
deps = ["ArgTools", "FileWatching", "LibCURL", "NetworkOptions"]
uuid = "f43a241f-c20a-4ad4-852c-f6b1247861c6"
version = "1.6.0"

[[deps.FilePathsBase]]
deps = ["Compat", "Dates", "Mmap", "Printf", "Test", "UUIDs"]
git-tree-sha1 = "9f00e42f8d99fdde64d40c8ea5d14269a2e2c1aa"
uuid = "48062228-2e41-5def-b9a4-89aafe57970f"
version = "0.9.21"

[[deps.FileWatching]]
uuid = "7b1f6079-737a-58dc-b8bc-7a2ca5c1b5ee"

[[deps.FiniteDiff]]
deps = ["ArrayInterface", "LinearAlgebra", "Requires", "Setfield", "SparseArrays"]
git-tree-sha1 = "2de436b72c3422940cbe1367611d137008af7ec3"
uuid = "6a86dc24-6348-571c-b903-95158fe2bd41"
version = "2.23.1"

    [deps.FiniteDiff.extensions]
    FiniteDiffBandedMatricesExt = "BandedMatrices"
    FiniteDiffBlockBandedMatricesExt = "BlockBandedMatrices"
    FiniteDiffStaticArraysExt = "StaticArrays"

    [deps.FiniteDiff.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.FixedPointNumbers]]
deps = ["Statistics"]
git-tree-sha1 = "335bfdceacc84c5cdf16aadc768aa5ddfc5383cc"
uuid = "53c48c17-4a7d-5ca2-90c5-79b7896eea93"
version = "0.8.4"

[[deps.ForwardDiff]]
deps = ["CommonSubexpressions", "DiffResults", "DiffRules", "LinearAlgebra", "LogExpFunctions", "NaNMath", "Preferences", "Printf", "Random", "SpecialFunctions"]
git-tree-sha1 = "cf0fe81336da9fb90944683b8c41984b08793dad"
uuid = "f6369f11-7733-5829-9624-2563aa707210"
version = "0.10.36"

    [deps.ForwardDiff.extensions]
    ForwardDiffStaticArraysExt = "StaticArrays"

    [deps.ForwardDiff.weakdeps]
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Future]]
deps = ["Random"]
uuid = "9fa8497b-333b-5362-9e8d-4d0656e87820"

[[deps.Hyperscript]]
deps = ["Test"]
git-tree-sha1 = "179267cfa5e712760cd43dcae385d7ea90cc25a4"
uuid = "47d2ed2b-36de-50cf-bf87-49c2cf4b8b91"
version = "0.0.5"

[[deps.HypertextLiteral]]
deps = ["Tricks"]
git-tree-sha1 = "7134810b1afce04bbc1045ca1985fbe81ce17653"
uuid = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
version = "0.9.5"

[[deps.IOCapture]]
deps = ["Logging", "Random"]
git-tree-sha1 = "8b72179abc660bfab5e28472e019392b97d0985c"
uuid = "b5f81e59-6552-4d32-b1f0-c071b021bf89"
version = "0.2.4"

[[deps.InlineStrings]]
deps = ["Parsers"]
git-tree-sha1 = "9cc2baf75c6d09f9da536ddf58eb2f29dedaf461"
uuid = "842dd82b-1e85-43dc-bf29-5d0ee9dffc48"
version = "1.4.0"

[[deps.InteractiveUtils]]
deps = ["Markdown"]
uuid = "b77e0a4c-d291-57a0-90e8-8db25a27a240"

[[deps.InvertedIndices]]
git-tree-sha1 = "0dc7b50b8d436461be01300fd8cd45aa0274b038"
uuid = "41ab1584-1d38-5bbf-9106-f11c6c58b48f"
version = "1.3.0"

[[deps.IrrationalConstants]]
git-tree-sha1 = "630b497eafcc20001bba38a4651b327dcfc491d2"
uuid = "92d709cd-6900-40b7-9082-c6be49f344b6"
version = "0.2.2"

[[deps.IteratorInterfaceExtensions]]
git-tree-sha1 = "a3f24677c21f5bbe9d2a714f95dcd58337fb2856"
uuid = "82899510-4779-5014-852e-03e436cf321d"
version = "1.0.0"

[[deps.JLLWrappers]]
deps = ["Artifacts", "Preferences"]
git-tree-sha1 = "7e5d6779a1e09a36db2a7b6cff50942a0a7d0fca"
uuid = "692b3bcd-3c85-4b1f-b108-f13ce0eb3210"
version = "1.5.0"

[[deps.JSON]]
deps = ["Dates", "Mmap", "Parsers", "Unicode"]
git-tree-sha1 = "31e996f0a15c7b280ba9f76636b3ff9e2ae58c9a"
uuid = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
version = "0.21.4"

[[deps.LaTeXStrings]]
git-tree-sha1 = "50901ebc375ed41dbf8058da26f9de442febbbec"
uuid = "b964fa9f-0449-5b57-a5c2-d3ea65f4040f"
version = "1.3.1"

[[deps.LibCURL]]
deps = ["LibCURL_jll", "MozillaCACerts_jll"]
uuid = "b27032c2-a3e7-50c8-80cd-2d36dbcbfd21"
version = "0.6.4"

[[deps.LibCURL_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll", "Zlib_jll", "nghttp2_jll"]
uuid = "deac9b47-8bc7-5906-a0fe-35ac56dc84c0"
version = "8.4.0+0"

[[deps.LibGit2]]
deps = ["Base64", "LibGit2_jll", "NetworkOptions", "Printf", "SHA"]
uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"

[[deps.LibGit2_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll"]
uuid = "e37daf67-58a4-590a-8e99-b0245dd2ffc5"
version = "1.6.4+0"

[[deps.LibSSH2_jll]]
deps = ["Artifacts", "Libdl", "MbedTLS_jll"]
uuid = "29816b5a-b9ab-546f-933c-edad1886dfa8"
version = "1.11.0+1"

[[deps.Libdl]]
uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"

[[deps.LineSearches]]
deps = ["LinearAlgebra", "NLSolversBase", "NaNMath", "Parameters", "Printf"]
git-tree-sha1 = "7bbea35cec17305fc70a0e5b4641477dc0789d9d"
uuid = "d3d80556-e9d4-5f37-9878-2ab0fcc64255"
version = "7.2.0"

[[deps.LinearAlgebra]]
deps = ["Libdl", "OpenBLAS_jll", "libblastrampoline_jll"]
uuid = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"

[[deps.LogExpFunctions]]
deps = ["DocStringExtensions", "IrrationalConstants", "LinearAlgebra"]
git-tree-sha1 = "18144f3e9cbe9b15b070288eef858f71b291ce37"
uuid = "2ab3a3ac-af41-5b50-aa03-7779005ae688"
version = "0.3.27"

    [deps.LogExpFunctions.extensions]
    LogExpFunctionsChainRulesCoreExt = "ChainRulesCore"
    LogExpFunctionsChangesOfVariablesExt = "ChangesOfVariables"
    LogExpFunctionsInverseFunctionsExt = "InverseFunctions"

    [deps.LogExpFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    ChangesOfVariables = "9e997f8a-9a97-42d5-a9f1-ce6bfc15e2c0"
    InverseFunctions = "3587e190-3f89-42d0-90ee-14403ec27112"

[[deps.Logging]]
uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"

[[deps.MIMEs]]
git-tree-sha1 = "65f28ad4b594aebe22157d6fac869786a255b7eb"
uuid = "6c6e2e6c-3030-632d-7369-2d6c69616d65"
version = "0.1.4"

[[deps.MacroTools]]
deps = ["Markdown", "Random"]
git-tree-sha1 = "2fa9ee3e63fd3a4f7a9a4f4744a52f4856de82df"
uuid = "1914dd2f-81c6-5fcd-8719-6d5c9610ff09"
version = "0.5.13"

[[deps.Markdown]]
deps = ["Base64"]
uuid = "d6f4376e-aef5-505a-96c1-9c027394607a"

[[deps.MbedTLS_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "c8ffd9c3-330d-5841-b78e-0817d7145fa1"
version = "2.28.2+1"

[[deps.Missings]]
deps = ["DataAPI"]
git-tree-sha1 = "ec4f7fbeab05d7747bdf98eb74d130a2a2ed298d"
uuid = "e1d29d7a-bbdc-5cf2-9ac0-f12de2c33e28"
version = "1.2.0"

[[deps.Mmap]]
uuid = "a63ad114-7e13-5084-954f-fe012c677804"

[[deps.MozillaCACerts_jll]]
uuid = "14a3606d-f60d-562e-9121-12d972cd8159"
version = "2023.1.10"

[[deps.NLSolversBase]]
deps = ["DiffResults", "Distributed", "FiniteDiff", "ForwardDiff"]
git-tree-sha1 = "a0b464d183da839699f4c79e7606d9d186ec172c"
uuid = "d41bc354-129a-5804-8e4c-c37616107c6c"
version = "7.8.3"

[[deps.NLsolve]]
deps = ["Distances", "LineSearches", "LinearAlgebra", "NLSolversBase", "Printf", "Reexport"]
git-tree-sha1 = "019f12e9a1a7880459d0173c182e6a99365d7ac1"
uuid = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
version = "4.5.1"

[[deps.NaNMath]]
deps = ["OpenLibm_jll"]
git-tree-sha1 = "0877504529a3e5c3343c6f8b4c0381e57e4387e4"
uuid = "77ba4419-2d1f-58cd-9bb1-8ffee604a2e3"
version = "1.0.2"

[[deps.NetworkOptions]]
uuid = "ca575930-c2e3-43a9-ace4-1e988b2c1908"
version = "1.2.0"

[[deps.OpenBLAS_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "Libdl"]
uuid = "4536629a-c528-5b80-bd46-f80d51c5b363"
version = "0.3.23+2"

[[deps.OpenLibm_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "05823500-19ac-5b8b-9628-191a04bc5112"
version = "0.8.1+2"

[[deps.OpenSpecFun_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "JLLWrappers", "Libdl", "Pkg"]
git-tree-sha1 = "13652491f6856acfd2db29360e1bbcd4565d04f1"
uuid = "efe28fd5-8261-553b-a9e1-b2916fc3738e"
version = "0.5.5+0"

[[deps.OrderedCollections]]
git-tree-sha1 = "dfdf5519f235516220579f949664f1bf44e741c5"
uuid = "bac558e1-5e72-5ebc-8fee-abe8a469f55d"
version = "1.6.3"

[[deps.Parameters]]
deps = ["OrderedCollections", "UnPack"]
git-tree-sha1 = "34c0e9ad262e5f7fc75b10a9952ca7692cfc5fbe"
uuid = "d96e819e-fc66-5662-9728-84c9c7592b0a"
version = "0.12.3"

[[deps.Parsers]]
deps = ["Dates", "PrecompileTools", "UUIDs"]
git-tree-sha1 = "8489905bcdbcfac64d1daa51ca07c0d8f0283821"
uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
version = "2.8.1"

[[deps.PeriodicalDates]]
deps = ["Dates", "Printf", "RecipesBase"]
git-tree-sha1 = "e616941f8093e50a373e7d51875143213f82eca4"
uuid = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
version = "2.0.0"

[[deps.Pkg]]
deps = ["Artifacts", "Dates", "Downloads", "FileWatching", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "REPL", "Random", "SHA", "Serialization", "TOML", "Tar", "UUIDs", "p7zip_jll"]
uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
version = "1.10.0"

[[deps.PlotlyBase]]
deps = ["ColorSchemes", "Dates", "DelimitedFiles", "DocStringExtensions", "JSON", "LaTeXStrings", "Logging", "Parameters", "Pkg", "REPL", "Requires", "Statistics", "UUIDs"]
git-tree-sha1 = "56baf69781fc5e61607c3e46227ab17f7040ffa2"
uuid = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
version = "0.8.19"

[[deps.PlutoPlotly]]
deps = ["AbstractPlutoDingetjes", "BaseDirs", "Colors", "Dates", "Downloads", "HypertextLiteral", "InteractiveUtils", "LaTeXStrings", "Markdown", "Pkg", "PlotlyBase", "Reexport", "TOML"]
git-tree-sha1 = "1ae939782a5ce9a004484eab5416411c7190d3ce"
uuid = "8e989ff0-3d88-8e9f-f020-2b208a939ff0"
version = "0.4.6"

    [deps.PlutoPlotly.extensions]
    PlotlyKaleidoExt = "PlotlyKaleido"
    UnitfulExt = "Unitful"

    [deps.PlutoPlotly.weakdeps]
    PlotlyKaleido = "f2990250-8cf9-495f-b13a-cce12b45703c"
    Unitful = "1986cc42-f94f-5a68-af5c-568840ba703d"

[[deps.PlutoUI]]
deps = ["AbstractPlutoDingetjes", "Base64", "ColorTypes", "Dates", "FixedPointNumbers", "Hyperscript", "HypertextLiteral", "IOCapture", "InteractiveUtils", "JSON", "Logging", "MIMEs", "Markdown", "Random", "Reexport", "URIs", "UUIDs"]
git-tree-sha1 = "ab55ee1510ad2af0ff674dbcced5e94921f867a9"
uuid = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
version = "0.7.59"

[[deps.PooledArrays]]
deps = ["DataAPI", "Future"]
git-tree-sha1 = "36d8b4b899628fb92c2749eb488d884a926614d3"
uuid = "2dfb63ee-cc39-5dd5-95bd-886bf059d720"
version = "1.4.3"

[[deps.PrecompileTools]]
deps = ["Preferences"]
git-tree-sha1 = "5aa36f7049a63a1528fe8f7c3f2113413ffd4e1f"
uuid = "aea7be01-6a6a-4083-8856-8a6e6704d82a"
version = "1.2.1"

[[deps.Preferences]]
deps = ["TOML"]
git-tree-sha1 = "9306f6085165d270f7e3db02af26a400d580f5c6"
uuid = "21216c6a-2e73-6563-6e65-726566657250"
version = "1.4.3"

[[deps.PrettyTables]]
deps = ["Crayons", "LaTeXStrings", "Markdown", "PrecompileTools", "Printf", "Reexport", "StringManipulation", "Tables"]
git-tree-sha1 = "88b895d13d53b5577fd53379d913b9ab9ac82660"
uuid = "08abe8d2-0d0c-5749-adfa-8a2ac140af0d"
version = "2.3.1"

[[deps.Printf]]
deps = ["Unicode"]
uuid = "de0858da-6303-5e67-8744-51eddeeeb8d7"

[[deps.REPL]]
deps = ["InteractiveUtils", "Markdown", "Sockets", "Unicode"]
uuid = "3fa0cd96-eef1-5676-8a61-b3b8758bbffb"

[[deps.Random]]
deps = ["SHA"]
uuid = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"

[[deps.RecipesBase]]
deps = ["PrecompileTools"]
git-tree-sha1 = "5c3d09cc4f31f5fc6af001c250bf1278733100ff"
uuid = "3cdcf5f2-1ef4-517c-9805-6587b60abb01"
version = "1.3.4"

[[deps.Reexport]]
git-tree-sha1 = "45e428421666073eab6f2da5c9d310d99bb12f9b"
uuid = "189a3867-3050-52da-a836-e630ba90ab69"
version = "1.2.2"

[[deps.Requires]]
deps = ["UUIDs"]
git-tree-sha1 = "838a3a4188e2ded87a4f9f184b4b0d78a1e91cb7"
uuid = "ae029012-a4dd-5104-9daa-d747884805df"
version = "1.3.0"

[[deps.SHA]]
uuid = "ea8e919c-243c-51af-8825-aaa63cd721ce"
version = "0.7.0"

[[deps.SentinelArrays]]
deps = ["Dates", "Random"]
git-tree-sha1 = "0e7508ff27ba32f26cd459474ca2ede1bc10991f"
uuid = "91c51154-3ec4-41a3-a24f-3f23e20d615c"
version = "1.4.1"

[[deps.Serialization]]
uuid = "9e88b42a-f829-5b0c-bbe9-9e923198166b"

[[deps.Setfield]]
deps = ["ConstructionBase", "Future", "MacroTools", "StaticArraysCore"]
git-tree-sha1 = "e2cc6d8c88613c05e1defb55170bf5ff211fbeac"
uuid = "efcf1570-3423-57d1-acb7-fd33fddbac46"
version = "1.1.1"

[[deps.SnoopPrecompile]]
deps = ["Preferences"]
git-tree-sha1 = "e760a70afdcd461cf01a575947738d359234665c"
uuid = "66db9d55-30c0-4569-8b51-7e840670fc0c"
version = "1.0.3"

[[deps.Sockets]]
uuid = "6462fe0b-24de-5631-8697-dd941f90decc"

[[deps.SortingAlgorithms]]
deps = ["DataStructures"]
git-tree-sha1 = "66e0a8e672a0bdfca2c3f5937efb8538b9ddc085"
uuid = "a2af1166-a08f-5f64-846c-94a0d3cef48c"
version = "1.2.1"

[[deps.SparseArrays]]
deps = ["Libdl", "LinearAlgebra", "Random", "Serialization", "SuiteSparse_jll"]
uuid = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"
version = "1.10.0"

[[deps.SpecialFunctions]]
deps = ["IrrationalConstants", "LogExpFunctions", "OpenLibm_jll", "OpenSpecFun_jll"]
git-tree-sha1 = "e2cfc4012a19088254b3950b85c3c1d8882d864d"
uuid = "276daf66-3868-5448-9aa4-cd146d93841b"
version = "2.3.1"

    [deps.SpecialFunctions.extensions]
    SpecialFunctionsChainRulesCoreExt = "ChainRulesCore"

    [deps.SpecialFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"

[[deps.StaticArraysCore]]
git-tree-sha1 = "36b3d696ce6366023a0ea192b4cd442268995a0d"
uuid = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
version = "1.4.2"

[[deps.Statistics]]
deps = ["LinearAlgebra", "SparseArrays"]
uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"
version = "1.10.0"

[[deps.StatsAPI]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1ff449ad350c9c4cbc756624d6f8a8c3ef56d3ed"
uuid = "82ae8749-77ed-4fe6-ae5f-f523153014b0"
version = "1.7.0"

[[deps.StringManipulation]]
deps = ["PrecompileTools"]
git-tree-sha1 = "a04cabe79c5f01f4d723cc6704070ada0b9d46d5"
uuid = "892a3eda-7b42-436c-8928-eab12a02cf0e"
version = "0.3.4"

[[deps.SuiteSparse]]
deps = ["Libdl", "LinearAlgebra", "Serialization", "SparseArrays"]
uuid = "4607b0f0-06f3-5cda-b6b1-a6196a1729e9"

[[deps.SuiteSparse_jll]]
deps = ["Artifacts", "Libdl", "libblastrampoline_jll"]
uuid = "bea87d4a-7f5b-5778-9afe-8cc45184846c"
version = "7.2.1+1"

[[deps.TOML]]
deps = ["Dates"]
uuid = "fa267f1f-6049-4f14-aa54-33bafae1ed76"
version = "1.0.3"

[[deps.TableTraits]]
deps = ["IteratorInterfaceExtensions"]
git-tree-sha1 = "c06b2f539df1c6efa794486abfb6ed2022561a39"
uuid = "3783bdb8-4a98-5b6b-af9a-565f29a5fe9c"
version = "1.0.1"

[[deps.Tables]]
deps = ["DataAPI", "DataValueInterfaces", "IteratorInterfaceExtensions", "LinearAlgebra", "OrderedCollections", "TableTraits"]
git-tree-sha1 = "cb76cf677714c095e535e3501ac7954732aeea2d"
uuid = "bd369af6-aec1-5ad0-b16a-f7cc5008161c"
version = "1.11.1"

[[deps.Tar]]
deps = ["ArgTools", "SHA"]
uuid = "a4e569a6-e804-4fa4-b0f3-eef7a1d5b13e"
version = "1.10.0"

[[deps.TensorCore]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1feb45f88d133a655e001435632f019a9a1bcdb6"
uuid = "62fd8b95-f654-4bbd-a8a5-9c27f68ccd50"
version = "0.1.1"

[[deps.Test]]
deps = ["InteractiveUtils", "Logging", "Random", "Serialization"]
uuid = "8dfed614-e22c-5e08-85e1-65c5234f0b40"

[[deps.TranscodingStreams]]
git-tree-sha1 = "71509f04d045ec714c4748c785a59045c3736349"
uuid = "3bb67fe8-82b1-5028-8e26-92a6c54297fa"
version = "0.10.7"
weakdeps = ["Random", "Test"]

    [deps.TranscodingStreams.extensions]
    TestExt = ["Test", "Random"]

[[deps.Tricks]]
git-tree-sha1 = "eae1bb484cd63b36999ee58be2de6c178105112f"
uuid = "410a4b4d-49e4-4fbc-ab6d-cb71b17b3775"
version = "0.1.8"

[[deps.URIs]]
git-tree-sha1 = "67db6cc7b3821e19ebe75791a9dd19c9b1188f2b"
uuid = "5c2747f8-b7ea-4ff2-ba2e-563bfd36b1d4"
version = "1.5.1"

[[deps.UUIDs]]
deps = ["Random", "SHA"]
uuid = "cf7118a7-6976-5b1a-9a39-7adc72f591a4"

[[deps.UnPack]]
git-tree-sha1 = "387c1f73762231e86e0c9c5443ce3b4a0a9a0c2b"
uuid = "3a884ed6-31ef-47d7-9d2a-63182c4928ed"
version = "1.0.2"

[[deps.Unicode]]
uuid = "4ec0a83e-493e-50e2-b9ac-8f72acf5a8f5"

[[deps.WeakRefStrings]]
deps = ["DataAPI", "InlineStrings", "Parsers"]
git-tree-sha1 = "b1be2855ed9ed8eac54e5caff2afcdb442d52c23"
uuid = "ea10d353-3f73-51f8-a26c-33c1cb351aa5"
version = "1.4.2"

[[deps.WorkerUtilities]]
git-tree-sha1 = "cd1659ba0d57b71a464a29e64dbc67cfe83d54e7"
uuid = "76eceee3-57b5-4d4a-8e66-0e911cebbf60"
version = "1.6.1"

[[deps.Zlib_jll]]
deps = ["Libdl"]
uuid = "83775a58-1f1d-513f-b197-d71354ab007a"
version = "1.2.13+1"

[[deps.libblastrampoline_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850b90-86db-534c-a0d3-1478176c7d93"
version = "5.8.0+1"

[[deps.nghttp2_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850ede-7688-5339-a07c-302acd2aaf8d"
version = "1.52.0+1"

[[deps.p7zip_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "3f19e933-33d8-53b3-aaab-bd5110c3b7a0"
version = "17.4.0+2"
"""

# ╔═╡ Cell order:
# ╟─943edb36-acc8-4b2a-94ab-c544f9eb279b
# ╟─1245aef9-18ce-42f5-af82-c2e6cce70798
# ╟─4618a663-f77e-4ccc-9b00-e84dbd5beb34
# ╠═a145e2fe-a903-11eb-160f-df7ea83fa3e6
# ╟─74de9f66-d5b4-4e0f-a75d-5177b1842191
# ╟─0bc2eb14-3b5a-4203-82dd-3ef2044a2c93
# ╟─7e025b57-5962-4ab8-85a0-a3cad37b1be5
# ╟─5999a598-0408-44f1-bd33-c4d0fa5a6006
# ╟─99fc937d-f798-418a-a57f-5ddc3feb5f3e
# ╟─9446db0c-db46-4d42-beca-55f152f0e8f5
# ╟─3d27554e-be8a-41a8-9fbf-1c7f3bc2cd84
# ╟─7d4589e5-37a5-4803-97bc-24c9a8ea61a5
# ╟─14a93d0a-2005-4406-9150-319d6583a518
# ╟─41c7afb6-a57b-45a7-8b9d-bb30902aab8b
# ╟─0836abe7-5ea6-4189-b783-a2215b6acd72
# ╟─4ce820d4-9eb2-4acd-92c7-820cf46d08ae
# ╟─d0e70b80-1e84-412c-9e5f-0161a0b0a935
# ╠═57d7d8ed-dce5-4177-b92b-1114b538814d
# ╟─2207f310-b6e0-40ca-9d11-6bd90adbd997
# ╟─66f39956-3665-4259-b10c-a82f3985b54b
# ╠═1dc9dce6-d373-4eb7-8e30-1030160accb4
# ╟─d61ba2bc-fb1e-4e00-afff-192a493a1956
# ╟─b0679f0a-69fc-427d-aae5-b3a243ccd407
# ╟─3b119e3e-e9bf-4426-9a4e-509504a7a122
# ╠═c496f682-73c2-40a8-88bf-c5f8554b9e3c
# ╟─89565b78-3ce4-4f0e-9ee2-0d563d7f9e68
# ╟─211db303-2224-4fb0-af03-f3558a27d206
# ╟─cace5be5-7a28-42ea-a958-d8eb5cced10d
# ╠═077586e0-70a0-4322-a531-3c71b6eab95f
# ╟─ee4cce74-40c5-41e6-b74e-122617a21d0d
# ╟─5a4c70b0-4f7c-4ef3-aabf-af1c46978637
# ╟─a7b2ef76-4626-4e89-9c78-98fa286923b3
# ╟─b53240b4-4fc7-4b07-acc2-b5381bcd6c86
# ╟─87f6de5e-ccbe-4295-a37f-123cfccaf3e8
# ╟─a6b6892e-c679-46e8-8553-65a3055fb472
# ╟─8493e2d6-7a73-4616-aa0b-11d7c8109c23
# ╟─b3f2f75f-ad9a-4e58-bb03-74de28379dbf
# ╟─348c030b-fd65-446c-8620-20a3f561aa81
# ╟─afa3ef46-b642-4f62-a1ca-31c4a456cb2b
# ╟─470ad9b2-d7be-41f6-9008-49fc4a245b06
# ╟─fb512cbd-9754-488b-89b7-91ef84dc350c
# ╟─b08087c8-3d3a-4531-917a-35ff7027d06b
# ╟─5a6ce46e-6109-42af-9563-1447e92a86fa
# ╟─53a03fb0-5e1b-450c-b720-2c71765f4154
# ╟─255fdba7-664d-4826-9280-7830dec5e74e
# ╟─5197f443-f1b9-4a0f-a64e-6c78cebe09c3
# ╟─7c31d1f7-7c30-4727-afce-16b7bd84275e
# ╟─72851987-a10f-4080-8cef-8277165aad53
# ╟─73ccae06-2006-4f2f-b110-fe34d082f677
# ╟─21817ce6-ccc3-46a1-9ee5-2f7309caf596
# ╟─288a991b-ea0e-4994-ae0c-db8ecfd94d08
# ╟─e2bb5f70-3e6c-4693-819e-b536af22a883
# ╟─1a4d2d63-b945-4861-bb56-c09aae400762
# ╟─46f43c27-7aba-4964-a7c4-f326dcbf951f
# ╟─d727d33c-9f15-46d6-8518-017ef36b6cf8
# ╟─5d0cee9b-73c6-4b7e-bb0f-6773be82f845
# ╟─c7da461d-1fc4-463e-bd46-900df67d1e03
# ╟─642d0c56-56e2-48d3-ba43-cc09e0f1f7c3
# ╠═a77a222e-aba3-4ac6-a5b0-a7551e3ccce4
# ╟─5cabdd52-eda2-4415-a650-76345ade196c
# ╟─d8c97fcb-7edc-4384-8da1-8b3f4b2ef471
# ╠═29089f61-955b-4f02-97a1-9e49ec796e96
# ╠═ae6e7a3f-4d2b-417f-aa66-af24a5803896
# ╟─6fe378c7-4970-4d12-8106-2ffcba89537d
# ╟─5eb27597-8fcf-4f35-8a49-818bdbce8951
# ╟─e52f724e-4530-4221-92ff-9f558d120db7
# ╟─34adc2d7-d7a6-4f62-b151-c71eff996074
# ╠═5652b23c-c152-4a8b-ac7d-b33d782c0800
# ╟─b2071081-ad56-43a8-8bf4-54802bfbc739
# ╟─a006eac2-59aa-43c1-b30a-8f7c2391ef27
# ╟─c38dbe18-a85a-4960-9c99-674196e0526d
# ╟─cb0d6593-5ca4-4afd-bddc-88506c4cf477
# ╟─afcdf0e6-4563-4bbb-a2db-6aa6c2d07b42
# ╟─495cbcdb-4120-4200-bfa6-5d1ad59308bb
# ╟─3e0f6675-3586-4f9f-8cec-cf87acae58f6
# ╟─46fae038-8319-4f88-b554-600ef7c762c8
# ╟─a39f29be-6494-44fc-a230-334aa552110f
# ╟─f11cdd5e-8b8f-47c6-bebd-a2a4ee067a3a
# ╟─5499984f-c56d-4a84-aa6b-24d48ec3b786
# ╟─d9c4f0f6-f54e-4bd8-ba73-0797fbd23dde
# ╟─aaa32024-887e-4dd2-81d6-c2b4f34db10f
# ╟─83eea9d2-0468-4d29-b780-fb0935cd9e03
# ╟─44a72782-4589-43db-81c1-0e88e0e20ae0
# ╟─4b401a4a-65ee-494e-8587-eb94d38668cb
# ╟─7a77fb62-270d-4447-8f14-c8788f540d6a
# ╟─ec202b59-9547-4565-ae95-42a4db603afa
# ╟─bc4b3b16-a96c-4758-bda9-36ea1dee0555
# ╟─add07024-b7eb-445d-b4f4-6a6757c2ecd3
# ╟─7f67d656-bb55-4097-ba49-10140f9b3502
# ╟─9ea169aa-0760-4051-8772-2873544c714e
# ╟─d4c73d36-fc14-4968-9166-660e05cd2078
# ╟─291adf2b-f5d7-40da-9778-f2218045273d
# ╟─9fb4d93f-ef2f-41a3-8c87-05f4210f6e9d
# ╟─bdea4838-cbd9-4947-bc74-b351658952c1
# ╟─dcd13560-0f73-4aaa-b59a-b7961d8cdc63
# ╟─bdd43163-6d69-41e5-a418-5535665ccab3
# ╟─79078ac3-3955-437a-8aed-88ef606d8aca
# ╟─81719a42-3d77-492b-a458-3132bab152a7
# ╟─aea60f3f-5c01-497f-8d24-fd4d1ffefbca
# ╟─a425ba3b-c991-4b41-8570-7f70c56ef812
# ╟─82a2c755-960e-4eb7-a55a-e333eb85fa5f
# ╠═4ac136d2-0413-4b4d-a990-9bf2a49ad482
# ╟─3bc3f9b4-c716-4655-a3cd-e83efbdbf4b9
# ╟─5ce15489-49a3-4942-b3dc-15a7629169c6
# ╟─292b1c34-b9d5-4468-98a9-4ee7a85d865b
# ╟─26fe310e-9ed8-4d09-bb82-a5bd39193dde
# ╟─63e8392d-c2b3-4a1a-b9f1-2acffe23ecb4
# ╟─3bed5d29-9973-4990-961a-53e53451854e
# ╟─9c5a5fcc-4655-4250-9214-1e819a862fa5
# ╟─8bfbcdd2-66b4-4884-8edd-71d3d8416a21
# ╟─0d216aac-314a-4ff0-9b31-f2f1e850655f
# ╟─ad3c4297-138f-4bdd-b839-e85ead198ee7
# ╟─1503e906-0783-407d-a3f7-134d3c99c766
# ╠═9fa87191-7c90-4738-a45a-acd929c8bd1b
# ╟─7d88deaf-f6c6-4ca3-a098-88d47d4e9b80
# ╟─56fe63eb-96fb-4dc9-ab4c-802ccb5e18a5
# ╟─82ccd7d9-2f97-4439-af15-0087392913e6
# ╟─99e824b2-e12c-4090-87cb-45b3d042ee79
# ╟─916b9c85-e357-4d10-bba1-2b641a4dbc28
# ╟─a94575d7-81e5-4929-b9df-c423016e865c
# ╟─3d73b76d-59e2-4249-9034-f9bbb2a1074b
# ╟─b6f5869c-62af-4e81-ae73-912fe522896e
# ╟─dde94490-9fdd-4417-90ae-0a6735eb505a
# ╟─2dce7165-029d-43cc-8358-9a8df3f86d2a
# ╟─475d7d83-5f9c-4fed-a6dc-31a46678d6bf
# ╟─5811e2cb-4448-4b03-a812-ab284b583c86
# ╟─f6081970-7d0e-4aba-b712-bca0a06d4319
# ╟─8362fd70-ae19-45f8-bb6d-386946cd793c
# ╟─8e2f6e74-d1e3-46fd-842d-bce5bcf08713
# ╟─edf08bd1-dcd2-4129-a61f-c1e4f6bb09d9
# ╟─0b858694-3d54-4f05-8132-9bfcd302534a
# ╟─242f70a8-bc87-4dfc-8d14-bc8861c5148a
# ╟─c9942e2d-318d-48b8-b145-96425791cae5
# ╟─056d9341-78f1-4cb1-8a8e-a71ff246cf9d
# ╟─da6d64b3-cea6-42b4-9270-97e5df74c5cf
# ╟─2275faad-ae60-49b6-a2e9-eda7a806b134
# ╟─d7e4c204-d21d-4119-a26f-124cf6ec5fa5
# ╟─0ce61106-cc15-44fa-a9a6-02ae2074154a
# ╟─6991c328-413a-4947-8542-a585e9010bca
# ╟─f7404380-0681-4466-ac61-a0f1dc4b94ef
# ╟─a7d4f49e-e317-44bd-bc77-a136e8182d59
# ╟─99e3138f-5fea-43e7-8f6b-195f2517c673
# ╟─c5e17c57-eb95-45de-aece-2493260cce7b
# ╟─1b801b74-99bf-4f0e-ac9e-b0da33341f1b
# ╟─25de8e33-de65-40b0-98d5-bdf7563910af
# ╟─6376af97-b159-4365-8928-93c596f7b3d7
# ╟─18685b35-d444-4a29-9947-9d244b02f241
# ╟─15499265-1c43-486b-a9d7-dadb8a522bd2
# ╟─8600ed97-f3d4-4c63-985a-ebd7ce7d5d55
# ╟─7c7af504-8508-40f9-a47d-b4518c2f4079
# ╟─9f0b3172-d9cd-4275-8b20-cb42e988cc0f
# ╟─9b3eab00-1c20-4caa-9232-fa2d1ce0a31d
# ╟─e96bccd3-554e-44b6-89f4-def910aac29a
# ╟─a9818a71-fc9c-483a-9482-2f062232e73d
# ╟─c44af435-f632-4542-b914-fe83dcde78a5
# ╟─a3b3c4ab-2d3d-4511-b3dd-36e0ec273cb0
# ╟─e3be2df9-6d5f-4541-ba35-ec65ebfeb4c3
# ╟─cc0f9f16-fd0b-4024-9fe7-744294d744c3
# ╟─1385bba0-7daf-4fe6-a9f8-9cc2fa29e600
# ╟─9b5ac60d-6732-4636-a2b2-08ab6f7297ad
# ╟─ecd1d9df-bec2-4d67-850b-1c263bfe2606
# ╟─1684b665-eae3-4e96-9f10-5909e09d9964
# ╟─2a8b4884-a1e7-4803-a2b1-6ce85955de93
# ╟─dad66466-0f3f-4908-92a4-50c5b20e5be5
# ╟─6ac7c37a-96a5-49d8-8fff-b76e381b6367
# ╟─f5fde724-21f9-4184-a317-8dfe75ec84ba
# ╟─e00c9d65-074e-4cb3-8e08-b32a58ee92c4
# ╟─1e98e928-68bd-4102-bdc8-2536b4615eaa
# ╟─1d7292a7-0dc6-4c0a-8e3c-fce761f3c499
# ╟─eeeb30c0-6b7d-42ff-93b8-dd647d72babe
# ╟─91fd4da1-abe0-4096-adcd-581d41fbfc33
# ╟─a81ad800-8dcc-4972-8245-5edf568aa611
# ╟─a2730369-1206-453d-930a-b6c779395cd5
# ╟─56bf8ed2-5786-4e51-b9c8-7a68a0690283
# ╟─e1c5c854-02c0-439c-9ba6-3f03be2a3d61
# ╟─f9d1d025-6b70-4a54-bc8a-7f7c5cad318a
# ╟─13f44f40-72d2-493f-a584-e17b6d0e102b
# ╟─f6d599fb-ac27-4c44-972f-28f300f43cdf
# ╟─ed9a0b2a-68fb-4996-81b2-60ba59248207
# ╟─b1ea211b-4ab8-49bd-96b7-dd8631cb689a
# ╟─87ec44a5-7b4e-4dde-84f1-126fc565a0b1
# ╟─a452dd71-b0f3-4bbb-a1b5-15522a262018
# ╟─a5519357-d4f8-4b65-aa83-6ccdd5485b4a
# ╟─47ac77f3-4f6d-4469-a2b7-edf35a049ed3
# ╟─51d0366d-3224-4a48-9e8e-7c8e4d41fd7e
# ╟─3a2b7a9b-0f24-4166-ba46-fc0b3df74f46
# ╟─9b68bbc2-d7f3-4bd7-9993-e4fe20363645
# ╟─5a8e44d3-ba71-4bb7-b6cc-509b08c9e1bb
# ╟─1b076f8f-f69f-40af-afe5-68749a409785
# ╟─1dfbe74a-61d7-48d8-823b-4d19efb3e6be
# ╟─960c426d-e69d-46f4-bc7c-a9c921b1a257
# ╟─29a9d34f-f239-43eb-9ce8-9c07c35d2d4e
# ╟─81536d10-9345-4889-b6d1-8fda40d2b0cb
# ╟─00000000-0000-0000-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000002
